package com.hrsk.cloud.eg.domain.api;

import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.LoanManagerService;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.EgressApiEndpointIntegrationModeEnum;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.EgressApiErrorCodeEnum;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.BeetlHelper;
import com.hrsk.cloud.eg.domain.common.GsonUtils;
import com.hrsk.pangu.domain.DomainFactory;
import com.hrsk.pangu.tool.exception.BizException;
import lombok.Data;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.tuple.Pair;

import java.util.Map;

/**
 * @author: bianlanzhou
 * @create: 2024-11-10 16:28
 * @description: API通道
 **/

@Data
public class ApiChannel {
    /**
     * 通道编码
     */
    private String channelCode;
    /**
     * 集成方式
     */
    private String integrationMode;
    /**
     * 权重
     */
    private Integer weight;
    /**
     * 请求/响应数据JSON配置
     */
    private Pair<String,String> configStrPair;
    /**
     * Http Api 请求配置
     */
    private HttpApiRequestConfig httpApiRequestConfig;
    /**
     * Http Api 响应配置
     */
    private String httpApiResponseConfig;

    /**
     * 评分，用于路由排序
     */
    private Integer score;

    /**
     * 构造函数
     * @param channelCode 渠道编码
     * @param integrationMode 集成方式
     * @param requestJsonConfig 请求配置
     * @param responseJsonConfig 响应配置
     */
    public ApiChannel(String channelCode,String integrationMode ,String requestJsonConfig, String responseJsonConfig) {
        this.channelCode = channelCode;
        this.integrationMode = integrationMode;
        configStrPair = Pair.of(requestJsonConfig,responseJsonConfig);
    }



    /**
     * 使配置生效
     */
    public void config(){
        if(StringUtils.equals(integrationMode,EgressApiEndpointIntegrationModeEnum.GUIDE.getCode())){
            httpApiRequestConfig = GsonUtils.fromJson(configStrPair.getLeft(),HttpApiRequestConfig.class);
            httpApiResponseConfig = configStrPair.getRight();
        }
    }

    /**
     * 调用
     * @param input 入参
     * @param httpClientFunc httpclient
     * @return 处理结果
     */
    public String invoke(Map<String,Object> input,Function<HttpApiRequest, HttpApiResponse> httpClientFunc,Function<String,Object> redisGetFunction,Function<RedisSetDto,Boolean> redisSetFunction){
        HttpApiResponse response = null;
        if(StringUtils.equals(integrationMode, EgressApiEndpointIntegrationModeEnum.GUIDE.getCode())){
            config();
            response = httpClientFunc.apply(new HttpApiRequest(httpApiRequestConfig).request(input));
            return BeetlHelper.render(httpApiResponseConfig,response);
        }else if(StringUtils.equals(integrationMode, EgressApiEndpointIntegrationModeEnum.CUSTOMIZE.getCode())){
            UserBaseInfoCmd userBaseInfoCmd = JSONObject.parseObject(input.get("user").toString(), UserBaseInfoCmd.class);
            EgLoanApiConfigInfoCmd apiConfigInfoCmd = JSONObject.parseObject(input.get("api").toString(), EgLoanApiConfigInfoCmd.class);
            PlanCmd planCmd = JSONObject.parseObject(input.get("plan").toString(), PlanCmd.class);
            LoanManagerService loanManagerService = DomainFactory.create(LoanManagerService.class);
            LoanDockingApi loanDockingApi = loanManagerService.apiRouter(planCmd, apiConfigInfoCmd);
            DataVo dataVo = loanDockingApi.qualityCheck(userBaseInfoCmd, planCmd, apiConfigInfoCmd, httpClientFunc, redisGetFunction, redisSetFunction);
            response.setData(dataVo);
            return  JSONObject.toJSONString(response);
        }else{
            throw new BizException(EgressApiErrorCodeEnum.ILLEGAL_INTEGRATION_MODE.getCode(),EgressApiErrorCodeEnum.ILLEGAL_INTEGRATION_MODE.getMessage());
        }
    }
}
