package com.hrsk.cloud.eg.domain.api.channel.customized;

import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import org.springframework.beans.BeansException;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.stereotype.Component;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

/**
 * @description:  获取对应的助贷service 处理方法
 * @param:
 * @return:
 * @author zhangyy
 * @date: 2024/11/27 16:14
 */
@Component
public class BizHandlerContext implements ApplicationContextAware {

    private final Map<ServerCodeEnums, LoanDockingApi> bizHandlerMap = new HashMap<>();



    public void putBizHandler(ServerCodeEnums type, LoanDockingApi handler) {
        bizHandlerMap.put(type, handler);
    }

    public LoanDockingApi getBizHandler(ServerCodeEnums type) {
        LoanDockingApi bizHandler = this.bizHandlerMap.get(type);
        if (bizHandler == null) {
            throw new RuntimeException("not.found.BizHandler");
        }
        return bizHandler;
    }

    @Override
    public void setApplicationContext(ApplicationContext applicationContext) throws BeansException {
        Map<String, LoanDockingApi> beansOfType = applicationContext.getBeansOfType(LoanDockingApi.class);
        Collection<LoanDockingApi> services = beansOfType.values();
        for (LoanDockingApi service : services) {
             ServerCodeEnums type = service.getType();
            bizHandlerMap.put(type, service);
        }
    }
}