package com.hrsk.cloud.eg.domain.api.channel.customized;

import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.JoinMethodEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl.*;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * @author zhangyy
 * @version 1.0
 * @description: LoanManagerService
 * @date 2024/11/27 16:15
 */
@Slf4j
@Service
public class LoanManagerService {


    @Resource
    private QingyuCreditService qingyuCreditService;
    @Resource
    private QingyuV2CreditService qingyuV2CreditService;
    @Resource
    private  QingyuV3CreditService qingyuV3CreditService;
    @Resource
    private  JinDieV2CreditService jinDieV2CreditService;
    @Resource
    private  JinDieV3CreditService jinDieV3CreditService;
    @Resource
    private RxkCreditService rxkCreditService;
    @Resource
    private BizHandlerContext handlerContext;

    @Resource
    private  HuirongCrmCreditService huirongCrmCreditService;

    @Resource
    private OpenApiAesCreditService openApiAesCreditService;

    @Resource
    private XiangKeDaCreditService xiangKeDaCreditService;

    @Resource
    private XinluCreditService xinluCreditService;

    @Resource
    private OpenApiCreditService openApiCreditService;


    public LoanDockingApi apiRouter(PlanCmd xdProduct,EgLoanApiConfigInfoCmd apiInfo) {
        if (null == xdProduct.getApiId()) return null;

        LoanDockingApi apiService = null;
        JoinMethodEnums method = JoinMethodEnums.getByCode(apiInfo.getIntegrationSystem());
        if (null == method) return null;
        switch (method) {
            case CRM_QY:
                apiService = qingyuCreditService;
                break;
            case CRM_XL:
                apiService = xinluCreditService;
                break;
            case OPEN_API:
                apiService = openApiCreditService;
                break;
            case CRM_QY_V2:
                apiService = qingyuV2CreditService;
                break;
            case CRM_XKD:
                apiService = xiangKeDaCreditService;
                break;
            case CRM_RXK:
                apiService = rxkCreditService;
                break;
            case HUIRONG_CRM:
                apiService = huirongCrmCreditService;
                break;
            case CRM_EC:
                break;
            case CRM_JD:
                apiService = jinDieV2CreditService;
                break;
            case CRM_JDV3:
                apiService = jinDieV3CreditService;
                break;
            case BUSI_API:
                apiService = handlerContext.getBizHandler(ServerCodeEnums.map.get(apiInfo.getIntegrationSystem()));
                break;
            case CRM_QY_V3:
                apiService = qingyuV3CreditService;
                break;
            case OPEN_API_AES:
                apiService = openApiAesCreditService;
                break;
            default:
                log.error("不支持的对接方式:productId={}",xdProduct.getPlanId());
        }
        return apiService;
    }

}
