package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.google.common.collect.Lists;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.KeyValueObject;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.ValueObjectTypeEnum;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HeadsUtil;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.concurrent.TimeUnit;

/**
 * @Author Liu Tao
 * @Date 2024 06 25 17 42
 **/
@Slf4j
@Service
public class BaiYiJinFuCreditService implements LoanDockingApi {

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.BaiYiJinFu;
    }

    @Data
    private static class CheckInfo {
        private String mobile;// 手机号码(MD5加密)
    }

    @Data
    private static class UserTokenInfo {
        private String username;// 	用户名
        private String password;// 	密码
    }

    @Data
    private static class ApplyInfo {
        private String customerName;//客户名称
        private String mobilePhone; //手机号码
        private Double loanamount; //贷款金额
        private String thirdCode; //第三方唯一码，唯一码不能重复，代表客户唯一标志
        private String thirdSource;//第三方来源，固定值、需要联系平台管理员获取
        private String channel;//渠道来源
        private String source;//客户所在城市
        private String houseflag;//房产：1：无、2：有
        private String carflag;//车产：1：无、2：有
        private String insuranceflag;//保险：N：否、Y：是
        private String socialflag;//社保：1：无、4：缴纳未满6个月、 5：缴纳6个月以上、2：有
        private String accumulationfundflag;//公积金：1：无、4：缴纳未满6个月、 5：缴纳6个月以上、2：有
        private String overdueflag;//有无逾期：1：无、2：有
        private String starlevel;//星级：0：0星、1：1星、 2：2星、3：3星、4：4星、5：长期跟进、6：重要、7：重点关注、8：五客管理、9：养客户、10：意向客户、11：债务优化、12：成交客户
        private String sex;//	性别：0：男、1：女、2：未知
        private String licensenoflag;//营业执照：1：无、2：有
        private String status;//状态：0：未受理、1：待开发、 2：邀约中、3：待维护、4：待上门、5：进件中、6：已上门、7：已签约、8：已回款、9：外地申请、10：废弃
        private String education;//学历：1：无、2：大专、3：本科、4：硕士
        private String remark;//客户备注
        private String age;//年龄
        private String profession;//职业，如：上班族 ，传具体的职业描述
        private String incomeType; //打卡方式， 1：银行代发、2：现金发放
        private int monthlyIncome; //月收入，工资
    }
    /**
     * 助贷对接 特殊处理，在调用撞库之前
     * @param userInfo
     * @param product
     * @return
     */
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc,Function<String,Object> redisGetFunction,Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit BaiYiJinFuCreditService qualityCheck begin...userId:{}",userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("佰亿金服对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setMobile(phoneMd5);
            String s = JSONObject.toJSONString(checkInfo);
            String token = String.valueOf(redisGetFunction.apply(String.format("zudai:token:%s:%s", "baiyi", "baiyitoken")));
            if (StringUtils.isBlank(token)){
                HttpApiResponse response = null;
                String tokenUrl=config.getString("tokenUrl");
                UserTokenInfo userInfo1=new UserTokenInfo();
                userInfo1.setUsername(config.getString("Username"));
                userInfo1.setPassword(config.getString("Password"));
                try{
                    HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(s,"post",tokenUrl));
                    response =httpClientFunc.apply(request);
                }catch (Exception e){
                    log.error("佰亿金服准入异常,异常信息：{}", e.getMessage(), e);
                }
                JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());
                if (jsonObject.getInteger("code")==200&&jsonObject.getString("token")!=null){
                    token=jsonObject.getString("token");
                    RedisSetDto redisSetDto=new RedisSetDto();
                    redisSetDto.setKey(String.format("zudai:token:%s:%s", "baiyi", "baiyitoken"));
                    redisSetDto.setValue(jsonObject.getString("token"));
                    redisSetDto.setTime(3);
                    redisSetDto.setTimeUnit(TimeUnit.HOURS);
                    redisSetFunction.apply(redisSetDto);
                }else {
                    return DataVo.fail("佰亿金服撞库失败，请联系系统管理员"+product.getPlanId());
                }
            }
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck BaiYiJinFuCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, s);
            HttpApiResponse response2 = null;
            try{
//                Map<String, String> head = new HashMap<>();
//                head.put("Content-Type", "application/json");
//                head.put("Authorization", "Bearer "+token);
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(s,"post",url, HeadsUtil.getJsonHeaders("Authorization","Bearer "+token)));
                response2 =httpClientFunc.apply(request);
            }catch (Exception e){
                log.error("佰亿金服准入异常,异常信息：{}", e.getMessage(), e);
            }
            JSONObject jsonObject=JSONObject.parseObject(response2.getData().toString());
            log.info("credit qualityCheck BaiYiJinFuCreditService response userId:{}, result:{}",userInfo.getUserId(), response2);
            if (jsonObject == null) {
                return DataVo.fail(product.getPlanId()+product.getPlanName());
            }
            if (jsonObject.getInteger("code")==200) {
                return DataVo.success("佰亿金服撞库成功",product.getPlanId());
            } else {
                return DataVo.fail("佰亿金服撞库成功",product.getPlanId());
            }
        } catch (Exception e) {
            return DataVo.fail("佰亿金服撞库失败，请联系系统管理员",product.getPlanId());
        }
    }

}
