package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Base64;
import org.springframework.stereotype.Component;
import javax.crypto.Cipher;
import javax.crypto.spec.SecretKeySpec;

/**
 * @Author Liu Tao
 * @Date 2024 07 05 16 36
 **/
@Slf4j
@Component
public class ChengDuYiHeShengCreditService implements LoanDockingApi {


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.ChengDuYiHeSheng;
    }

    @Data
    private static class CheckInfo{
        private String md5;//md5加密后的手机号，32位小写
    }


    @Data
    private static class ApplyInfo {
        private String order_id;//订单id
        private String name;//姓名
        private Integer age;//年龄
        private String telephone;//手机号
        private String gender;//性别 （1男 2女）
        private String province;//省份
        private String city;//城市
        private String loan_time;//贷款时间//月
        private Integer loan_amount;//贷款金额 万
        private String sec_code;//安全码
        private Integer has_job;//是否有工作 1有，2没有
        private Integer has_income;//是否有收入 1有2没有
        private Integer has_house;//是否有房
        private Integer has_car;//是否有车
        private Integer has_socins;//是否有社保
        private Integer has_fund;//是否有公积金
        private Integer has_ins;//是否有商业保险
        private Integer has_cc;//是否有信用卡，1有，2没有
        private Integer has_ovd;//是否有逾期，1有，2没有
        private Integer has_ent;//是否有企业，1有，2没有
        private Integer has_ali_score;//是否有芝麻分，0，0-599，1.600-649，2.650-699,3.700+
    }

        public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc,Function<String,Object> redisGetFunction,Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit ChengDuYiHeShengCreditService qualityCheck begin...userId:{}",userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("成都亿禾生对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setMd5(phoneMd5);

            JSONObject json=new JSONObject();
            json.put("appid", String.valueOf(config.getString("appid")));
            json.put("data", encrypt(JSON.toJSONString(checkInfo), config.getString("key")));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck ChengDuYiHeShengCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            HttpApiResponse response = null;
            try {
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(JSON.toJSONString(json),"post",url));
                response =httpClientFunc.apply(request);
            }catch (Exception e){
                log.error("成都亿禾生准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck ChengDuYiHeShengCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject = JSONObject.parseObject(response.getData().toString());

            if (jsonObject == null) {
                return DataVo.timeout( product.getPlanId(),product.getPlanName());
            }
            if (jsonObject.getInteger("code") ==200 ) {
                return DataVo.success(0, "成都亿禾生撞库成功", product.getPlanId());
            } else {
                return DataVo.success(1, "成都亿禾生撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("成都亿禾生撞库失败", e);
            return DataVo.success(1, "成都亿禾生撞库失败，请联系系统管理员", product.getPlanId());
        }

    }
    public static String encrypt(String sSrc, String sKey) {
        try {
            if (sKey == null) {
                System.out.print("Key为空null");
                return null;
            }
            if (sKey.length() != 16) {
                System.out.print("Key长度不是16位");
                return null;
            }
            byte[] raw = sKey.getBytes("utf-8");
            SecretKeySpec skeySpec = new SecretKeySpec(raw, "AES");
            Cipher cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");//"算法/模式/补码方式"
            cipher.init(Cipher.ENCRYPT_MODE, skeySpec);
            byte[] encrypted = cipher.doFinal(sSrc.getBytes("utf-8"));

            return Base64.encodeBase64String(encrypted);//此处使用BASE64做转码功能，同时能起到2次加密的作用。
        } catch (Exception e) {
             return null;
        }

    }


}
