package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;


import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import java.util.Objects;

/**
 * @Descrption
 * @Author: chend
 * @Date: 2023/2/6
 * @Version V1.0
 **/
@Service
@Slf4j
public class ChuanjinCreditService implements LoanDockingApi {

    private final static String qualityCheckPath = "customers/check/MD5Encrypt";
    private final static String applyPath = "customers";

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.ChuanJin;
    }
    @Data
    private static class CheckInfo {
        private String phone_encrypt;

        private String company_id;
    }

    @Data
    private static class ResResult {
        private Integer data;

        private Integer code;

        private String msg;
    }

    @Data
    private static class ApplyInfo {
        private String name;
        private String phone;
        private String gender;
        private Integer age;
        private Integer limit;
        //        private String income_year;
        private String provider_code;
        private String education;
        private String career;
        private String company_id;
    }


        public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc,Function<String,Object> redisGetFunction,Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit ChuanjinCreditService qualityCheck begin...userId:{}", userInfo.getUserId());

            Object requestConfig = HessianUtils.deserialize(configInfo.getRequestConfig()) ;
            JSONObject config = JSONObject.parseObject(requestConfig.toString());
            log.info("川金对接参数:{}", JSON.toJSONString(config));
            String url = config.getString("url") + qualityCheckPath;
            HttpApiResponse response = null;
            try {

                url = url + "?phone_encrypt=" + userInfo.getUserMobileMD5() + "&company_id=" + config.getString("channelSource");
                log.info("credit qualityCheck ChuanjinCreditService request userId:{}, url:{}", userInfo.getUserId(), url);
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(null,"post",url));
                response =httpClientFunc.apply(request);
            } catch (Exception e) {
                log.error("川金准入异常,异常信息：{}", e.getMessage(), e);
            }
            JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());
            log.info("credit qualityCheck ChuanjinCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            return Objects.equals(0, jsonObject.getString("data")) ? DataVo.success(0, "川金撞库成功", product.getPlanId())
                    : DataVo.fail(1, jsonObject.getString("msg"), product.getPlanId());

        } catch (Exception e) {
            log.error("川金撞库失败", e);
            return DataVo.fail(1, "川金撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

}
