package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.google.common.collect.Lists;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.KeyValueObject;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.ValueObjectTypeEnum;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Base64;
import org.springframework.stereotype.Service;

import javax.crypto.Cipher;
import javax.crypto.spec.SecretKeySpec;
import java.util.List;

/**
 * @Author Liu Tao
 * @Date 2024 04 23 14 36
 **/
@Slf4j
@Service
public class FuChengCreditService implements LoanDockingApi {



    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.FuCheng;
    }

    @Data
    private static class CheckInfo{
        private String phoneMd5;// 手机号md5
    }
    @Data
    private static class ApplyInfo{
        private String phone;//手机号（明文）
        private String name; //客户姓名
        private String city; //城市编码（例：310101）
        private Integer amount; //贷款金额，单位万元
        private Integer car;//是否有车  0 没有  1有
        private Integer house;//是否有房  0没有  1有
        private Integer socialSecurity; //是否有社保
        private Integer accumulationFund; //是否有公积金
        private Integer businessLicense; //是否有营业执照
    }


        public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc,Function<String,Object> redisGetFunction,Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit FuChengCreditService qualityCheck begin...userId:{}",userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("福程对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setPhoneMd5(phoneMd5);
            JSONObject json = new JSONObject(){{
                put("data",encrypt(JSON.toJSONString(checkInfo),config.getString("key")));
            }};
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck FuChengCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, phoneMd5);
            HttpApiResponse response = null;
            try{
//                Map<String, String> head = new HashMap<>();
//                head.put("Content-Type", "application/json");
//                head.put("channelSign", config.getString("channelSign"));
                List<KeyValueObject> headers = Lists.newArrayList();
                KeyValueObject head=new KeyValueObject();
                head.setType(ValueObjectTypeEnum.BASIC.getType());
                head.setKey("Content-Type");
                head.setValue("application/json");
                KeyValueObject head2=new KeyValueObject();
                head2.setType(ValueObjectTypeEnum.BASIC.getType());
                head2.setKey("channelSign");
                head2.setValue(config.getString("channelSign"));
                headers.add(head2);
                headers.add(head);
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(json.toJSONString(),"post",url,headers));
                response =httpClientFunc.apply(request);

            }catch (Exception e){
                log.error("福程准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck FuChengCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());
            if (jsonObject.getString("code").equals("200")) {
                return DataVo.success(0, "福程撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "福程撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            return DataVo.fail(1, "福程撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

    public static String encrypt(String sSrc, String sKey) throws Exception {
        if (sKey == null) {
            System.out.print("Key为空null");
            return null;
        }
        if (sKey.length() != 16) {
            System.out.print("Key长度不是16位");
            return null;
        }
        byte[] raw = sKey.getBytes("utf-8");
        SecretKeySpec skeySpec = new SecretKeySpec(raw, "AES");
        Cipher cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");//"算法/模式/补码方式"
        cipher.init(Cipher.ENCRYPT_MODE, skeySpec);
        byte[] encrypted = cipher.doFinal(sSrc.getBytes("utf-8"));

        return Base64.encodeBase64String(encrypted);//此处使用BASE64做转码功能，同时能起到2次加密的作用。
    }
}
