package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.google.common.collect.Lists;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.KeyValueObject;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.ValueObjectTypeEnum;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HeadsUtil;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;

/**
 * 格鑫金服API接单
 */
@Service
@Slf4j
public class GexinjinfuCreditService implements LoanDockingApi {


    private final String qualityCheckPath = "/api/rsatg/checkmobile";

    private final String applyPath = "/api/rsatg/add";


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.Gexinjinfu;
    }

    @Data
    public static class CheckData{

        private String channel_code;
        private String mobile_md5;
        private String channel_secret_key;
    }

    @Data
    private static class CheckInfo{
        private String client_id;

        private String client_secret;

        private CheckData data;


    }
    @Data
    private static class ResultHt{
        private Integer status;
        private String msg;
    }


    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *  {"channelSource":"birong","url":"http://apitest.shlyxxjs.com","key":"mgjr@3des123#dhjr9763089"}
     */
        public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc,Function<String,Object> redisGetFunction,Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit GexinjinfuCreditService qualityCheck begin...userId:{}",userInfo.getUserId());

            String configJson = HessianUtils.deserialize(configInfo.getRequestConfig()).toString();
            JSONObject gexinjinfuJointDTO = JSON.parseObject(configJson);
            log.info("格鑫金服对接参数:{}", JSON.toJSONString(gexinjinfuJointDTO));
            String md5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            String url = gexinjinfuJointDTO.getString("url") + qualityCheckPath  + "?mobnum_md5=" +  md5;
            log.info("credit qualityCheck GexinjinfuCreditService request userId:{}, url:{}, checkData:{}",userInfo.getUserId(), url);
            HttpApiResponse response = null;
            try{
//                Map<String, String> head = new HashMap<>();
//                head.put("Content-Type", "application/x-www-form-urlencoded; charset=UTF-8");
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(null,"post",url, HeadsUtil.getFromHeaders(null,null)));
                response =httpClientFunc.apply(request);
            }catch (Exception e){
                log.error("格鑫金服准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck GexinjinfuCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());
            return Objects.equals(200, jsonObject.getString("status")) ? DataVo.success(0, "格鑫金服撞库成功", product.getPlanId())
                    : DataVo.fail(jsonObject.getString("msg"), product.getPlanId());
        } catch (Exception e) {
            log.error("格鑫金服撞库失败", e);
            return DataVo.fail(1, "格鑫金服撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

}
