package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

/**
 * @Author Liu Tao
 * @Date 2023 09 22 17 08
 *广东昊恩API
 **/
@Slf4j
@Service
public class GuangDongHaoEnCreditService implements LoanDockingApi {


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.GuangDongHaoEn;
    }

    @Data
    private static class CheckInfo{
        private String appid;//数据标识
        private String mobileEncrypt;//手机号MD5加密32位小写字符串
    }

    @Data
    private static class ApplyInfo{
        private String appid; //数据标识
        private String name; //姓名
        private String mobile;//手机号
        private String cardNo;//身份证
        private Integer gender;//性别; 0-女 1-男
        private String city;//城市（格式：xx市）
        private Integer amount;//申请金额(万)
        private String period;//申请期限(月)
        private Integer monthlyIncome;//月收入(元)
        private Integer age;//年龄(18-99)
        private Integer houseType;//房产; 0-无 1-有
        private Integer carType;//车产; 0-无 1-有
        private Integer socialInsurance;//社保; 0-无 1-有
        private Integer commercialInsurance;//商业保险; 0-无 1-有
        private Integer accumulationFund;//公积金; 0-无 1-有
        private Integer entrepreneur;//是否企业主; 0-否 1-是
        private Integer credit;//信用情况
        private Integer zhima;//芝麻分
        private Integer additional;//其他信息
    }
        public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc,Function<String,Object> redisGetFunction,Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit GuangDongHaoEnCreditService qualityCheck begin...userId:{}",userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("广东昊恩对接参数:{}", JSONObject.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setMobileEncrypt(phoneMd5);
            checkInfo.setAppid(config.getString("appid"));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck GuangDongHaoEnCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            HttpApiResponse response = null;
            try{
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(JSON.toJSONString(checkInfo),"post",url));
                response =httpClientFunc.apply(request);
            }catch (Exception e){
                log.error("广东昊恩准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck GuangDongHaoEnCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
             JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());

            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("code") == 200) {
                return DataVo.success(0, "广东昊恩撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "广东昊恩撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("广东昊恩撞库失败", e);
            return DataVo.fail(1, "广东昊恩撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

}
