package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HeadsUtil;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

/**
 * 哈密瓜API接单
 */
@Service
@Slf4j
public class HamiguaCreditService implements LoanDockingApi {


    private final String qualityCheckPath = "/v1/api/customer/repeat/check";

    private final String applyPath = "/v1/api/customer/media/create";

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.Hamigua;
    }

    @Data
    public static class CheckData{
        private String mobile_md5;
        private String city;
    }

    @Data
    private static class CheckInfo{
        private String client_id;

        private String client_secret;

        private CheckData data;


    }
    @Data
    private static class ResultHt{
        private Integer code;
        private String message;
    }

    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *  {"channelSource":"birong","url":"http://apitest.shlyxxjs.com","key":"mgjr@3des123#dhjr9763089"}
     */
        public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc,Function<String,Object> redisGetFunction,Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit HamiguaCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
//            XdProductJointConfig xdProductJointConfig = xdProductJointConfigMapper.selectById(product.getJointType());

            String configJson = HessianUtils.deserialize(configInfo.getRequestConfig()).toString() ;
            JSONObject hamiguaJointDTO = JSON.parseObject(configJson);
            log.info("哈密瓜对接参数:{}", JSON.toJSONString(hamiguaJointDTO));
//            CheckInfo checkInfo = new CheckInfo();
            CheckData checkData = new CheckData();
            checkData.setCity(userInfo.getCompanyCity());
            checkData.setMobile_md5(userInfo.getUserMobileMD5());
//            checkInfo.setClient_id(hamiguaJointDTO.getClientId());
//            checkInfo.setClient_secret(hamiguaJointDTO.getClientSecret());
//            checkInfo.setData(checkData);
            String url = hamiguaJointDTO.getString("url") + qualityCheckPath;
            log.info("credit qualityCheck HamiguaCreditService request userId:{}, url:{}, checkData:{}",userInfo.getUserId(), url, checkData);
            HttpApiResponse response = null;
            try{
                Map<String, String> head = new HashMap<>();
                head.put("Content-Type", "application/json");
                head.put("secret", hamiguaJointDTO.getString("clientSecret"));
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(JSON.toJSONString(checkData),"post",url, HeadsUtil.getJsonHeaders("secret",hamiguaJointDTO.getString("clientSecret"))));
                response =httpClientFunc.apply(request);
            }catch (Exception e){
                log.error("哈密瓜准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck HamiguaCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());
            return Objects.equals(10, jsonObject.getString("code")) ? DataVo.success(0, "哈密瓜撞库成功", product.getPlanId())
                    : DataVo.fail(jsonObject.getString("message"), product.getPlanId());
        } catch (Exception e) {
            log.error("哈密瓜撞库失败", e);
            return DataVo.fail(1, "哈密瓜撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

}
