package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;

import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HeadsUtil;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;

import java.util.Collections;

/**
 * @Author zjc
 * @Date 2024 07 17 14 53
 **/
@Slf4j
@Component
public class HengYangJiuZhenCreditService implements LoanDockingApi {



    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.HengYangJiuZhen;
    }

    @Data
    private static class CheckInfo{
        private String phone;
        private String source;
        private String city;
    }

    @Data
    private static class ApplyInfo{
        private String qdName;//渠道ID
        private String name;//姓名
        private String phone;//手机号
        private Integer price;//贷款金额
        private Integer house;//是否有房，1有，0无
        private Integer car;//是否有⻋，1有，0无
        private Integer insurance;//是否有寿险，1有，0无
        private Integer fund;//是否有公积⾦，1有，0无
        private Integer socital;//是否有社保，1有，0无
        private String city;//所在城市

        private Integer xyk;//信用卡
        private Integer wld;
        private Integer qyns;
        private Integer df;
        private String source;
        private Integer age;
        private Integer loan_periods;//
        private Integer business_license;//营业执照（0无1有）


    }

        public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc,Function<String,Object> redisGetFunction,Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
//            log.info("credit YunHaiLianDongCreditService qualityCheck begin...userId:{}", userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());

            String url = config.getString("checkUrl");

            MultiValueMap<String, String> params = new LinkedMultiValueMap<>();
            params.put("phone", Collections.singletonList(userInfo.getUserMobileMD5()));
            params.put("source", Collections.singletonList(config.getString("source")));
            params.put("city", Collections.singletonList(userInfo.getCityAllName()));
            HttpApiRequest httpApiRequest=new HttpApiRequest(HttpApiRequestConfig.postRequest(String.valueOf(params),"post",url, HeadsUtil.getFromHeaders(null,null)));
            log.info("credit qualityCheck HengYangJiuZhenCreditService request userId:{}, url:{}, params:{}", userInfo.getUserId(), url, params);
            HttpApiResponse response = null;
            try {
                 response = httpClientFunc.apply(httpApiRequest);
//                response =getRestTemplate().postForObject(url,checkInfo, String.class);
            } catch (Exception e) {
                log.error("衡阳玖臻准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck HengYangJiuZhenCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
              JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());
//            log.info("credit qualityCheck YunHaiLianDongCreditService response userId:{}, jsonObject:{}", userInfo.getUserId(), jsonObject);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("status") == 200) {
                return DataVo.success(0, "衡阳玖臻撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "衡阳玖臻撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("衡阳玖臻撞库失败", e);
            return DataVo.fail(1, "衡阳玖臻撞库失败，请联系系统管理员", product.getPlanId());
        }
    }



}
