package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HeadsUtil;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;



/**
 * @Author Liu Tao
 * @Date 2024 09 03 09 49
 **/
@Slf4j
@Service
public class HongShengJinFuCreditService implements LoanDockingApi {



    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.HongShengJinFu;
    }

    @Data
    private static class CheckInfo {
        private String md5;// 手机号（32位MD5加密字符串）
    }

    @Data
    private static class ApplyInfo {
        private String name;//客户姓名
        private String sex; //性别(“男”或“女”)
        private String mobile; //手机号
        private String check_num;//验证码（无则留空）
        private Integer money;//贷款额度(如：20，即单位为万)
        private String city; //城市不包含市
        private Integer age;//年龄
        private String shebao; //社保(“有”或“无”)
        private String gongjijin; //公积金(“有”或“无”)
        private String credit_card;//信用卡(“有”或“无”)
        private String baodan_is;//保单(“有”或“无”)
        private String license; //营业执照（“有”或“无”）
        private String house;//房(“有”或“无”)
        private String car; //是否有车(“有”或“无”)
        private String isbankpay; //银行代发(“是”或“否”)
        private String source;//（必填）贷款来源(固定值，具体需要和对接人确定)
        private String meiti;//媒体名称(投放媒体名称，第三方私下内容以便其对数据分析)
        private String remark;
    }

        public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("弘盛金服对接参数:{}", JSONObject.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            String url = config.getString("checkUrl");
            log.info("弘盛金服开始撞库,请求地址：{},md5:{}", url, phoneMd5);
            MultiValueMap<String, String> params= new LinkedMultiValueMap<String, String>();
            params.add("md5", phoneMd5);
            HttpApiResponse response = null;
            try{
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(String.valueOf(params),"post",url, HeadsUtil.getFromHeaders(null,null)));
                response = httpClientFunc.apply(request);

            } catch (Exception e) {
                log.error("弘盛金服准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("弘盛金服撞库响应：{},md5:{}", response, phoneMd5);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
              JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());
            if (jsonObject.getString("code").equals("12")) {
                return DataVo.success(0, "弘盛金服撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "弘盛金服撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            return DataVo.fail(1, "弘盛金服撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

}
