package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HeadsUtil;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;

/**
 * @Author Liu Tao
 * @Date 2024 07 04 13 49
 **/
@Slf4j
@Service
public class HongXinPuHuiCreditService implements LoanDockingApi {





    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.HongXinPuHui;
    }

    @Data
    private static class CheckInfo{
        private String mobile_md5;//md5加密后的手机号，32位小写
        private Integer company;//指定推送商户id，当前默认都传“3
        private Integer is_encrypt;//是否加密，1:是  0:否
    }


    @Data
    private static class ApplyInfo {
        private String name;//姓名
        private String mobile;//加密字符串
        private Integer channel;//渠道来源（固定传16）
        private Integer company;//商户id,默认传“3”
        private Integer sex;//性别 （1男 2女）
        private Integer loan_limit;//额度 (比如: 100000，单位：元）
        private Integer room;//是否有房产（1：有  0：无）
        private Integer car;//是否有车产（ 1：有  0：无)
        private Integer accumulation;//是否有公积金 ( 1：有  0：无)
        private Integer social;//是否有社保 ( 1：有  0：无 )
        private Integer policy;//是否有保单 (  1：有  0：无 )
        private Integer business;//是否有营业执照 ( 1：有  0：无 )
        private Integer issued;//是否有打卡工资 ( 1：有  0：无 )
        private Integer enterprise;//是否有企业纳税 (  1：有  0：无 )
        private Integer credit;//是否有信用卡 (  1：有  0：无 )
        private Integer is_encrypt;//是否加密（1：是 0:否）
    }

        public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit HongXinPuHuiCreditService qualityCheck begin...userId:{}",userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("弘鑫普惠对接参数:{}", JSONObject.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setMobile_md5(phoneMd5);
            checkInfo.setCompany(config.getInteger("company"));
            checkInfo.setIs_encrypt(0);

            Map<String, String> requestData = new HashMap<>();
            requestData.put("mobile_md5", String.valueOf(checkInfo.getMobile_md5()));
            requestData.put("company", String.valueOf(checkInfo.getCompany()));
            requestData.put("is_encrypt", String.valueOf(checkInfo.getIs_encrypt()));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck HongXinPuHuiCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            HttpApiResponse response = null;
            try{
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(String.valueOf(requestData),"post",url, HeadsUtil.getFromHeaders(null,null)));
                response =httpClientFunc.apply(request);
            }catch (Exception e){
                log.error("弘鑫普惠准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck HongXinPuHuiCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());
            if (jsonObject.getInteger("code")==0) {
                return DataVo.success(0, "弘鑫普惠撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "弘鑫普惠撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("弘鑫普惠撞库失败", e);
            return DataVo.fail(1, "弘鑫普惠撞库失败，请联系系统管理员", product.getPlanId());
        }

    }


}
