package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Objects;

/**
 * 惠融crmAPI接单
 */
@Service
@Slf4j
public class HuirongCrmCreditService implements LoanDockingApi {
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.HUIRONG_CRM;
    }

    @Data
    public static class CheckData {
        private String chanelCode;
        private String secretKey;
        private String attackPhone;
        private String merchantNo;
    }

    @Data
    private static class ResultHt {
        private Integer code;
        private String msg;
        private JSONObject data;
    }



    /**
     * 撞库 实现单个用户撞库
     *
     * @return {"channelSource":"birong","url":"http://apitest.shlyxxjs.com","key":"mgjr@3des123#dhjr9763089"}
     */
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit HuirongCrmCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            String url = config.getString("checkUrl");
            CheckData checkData = new CheckData();
            if(StringUtils.isNotBlank(userInfo.getUserMobile())){
                checkData.setAttackPhone(Md5Util.encoderByMd5(userInfo.getUserMobile()));
            }else{
                checkData.setAttackPhone(userInfo.getUserMobileMD5());
            }

            checkData.setSecretKey(config.getString("secretKey"));
            checkData.setChanelCode(config.getString("channelCode"));
            checkData.setMerchantNo(product.getBid());
            String requestJson = JSON.toJSONString(checkData);
            log.info("credit qualityCheck HuirongCrmCreditService request userId:{}, url:{},requestParam:{}", userInfo.getUserId(), url, requestJson);
            HttpApiResponse response = null;
            try {
               HttpApiRequest httpApiRequest = new HttpApiRequest(HttpApiRequestConfig.postRequest(requestJson,"post",url));
                response = httpClientFunc.apply(httpApiRequest);
                //post方式如果出现对接 请求体 为空参考这种方式
              log.info("hui ron result {}",JSONObject.toJSONString(response));
            } catch (Exception e) {
                log.error("惠融crm准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck HuirongCrmCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }

            JSONObject data =JSONObject.parseObject(response.getData().toString()) ;
            Integer status = data.getInteger("status");
            return Objects.equals(0, status) ? DataVo.success(0, "惠融crm撞库成功", product.getPlanId())
                    : DataVo.fail(data.getString("msg"), product.getPlanId());
        } catch (Exception e) {
            log.error("惠融crm撞库失败", e);
            return DataVo.fail(1, "惠融crm撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

}
