package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.util.Objects;

/**
 * @Descrption
 * @Author: chend
 * @Date: 2023/5/15
 * @Version V1.0
 **/
@Component
@Slf4j
public class HuixinCreditService implements LoanDockingApi {
    private final String qualityCheckPath = "pushdata.ashx?type=CheckMobilePhone";

    private final String applyPath = "pushdata.ashx";


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.Huixin;
    }

    @Data
    public static class HuiXinJointDTO {

        private String url;

        private String merNo;

        private String encKey;

        private String sourceType;
    }


    @Data
    public static class CheckData {
        private String merNo;
        private String params;
    }

    @Data
    private static class CheckInfo {
        private String phoneMd5;

        private String sign;


    }

    @Data
    private static class ResultHt {
        private String code;
        private String msg;
        private boolean status;
    }


    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return {"channelSource":"birong","url":"http://apitest.shlyxxjs.com","key":"mgjr@3des123#dhjr9763089"}
     */
        public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit HuixinCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
//            XdProductJointConfig xdProductJointConfig = xdProductJointConfigMapper.selectById(product.getJointType());

            String configJson = HessianUtils.deserialize(configInfo.getRequestConfig()).toString();
            JSONObject huiXinJointDTO = JSONObject.parseObject(configJson);
            log.info("汇鑫对接参数:{}", JSONObject.toJSONString(huiXinJointDTO));

            String phoneMd5 = userInfo.getUserMobileMD5();
            JSONObject param = new JSONObject() {{
                put("phoneMd5", phoneMd5);
            }};

            String url = huiXinJointDTO.getString("url") + qualityCheckPath;
            log.info("credit qualityCheck HuixinCreditService request userId:{}, url:{}, data:{}", userInfo.getUserId(), url, param);

            HttpApiResponse response = null;
            try {
                HttpApiRequest httpApiRequest=new HttpApiRequest(HttpApiRequestConfig.postRequest(JSONObject.toJSONString(param),"post",url));
                response = httpClientFunc.apply(httpApiRequest);
            } catch (Exception e) {
                log.error("汇鑫准入异常,异常信息：{}", e.getMessage(), e);
            }

            log.info("credit qualityCheck HuixinCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }


            JSONObject jsonObject = JSONObject.parseObject(decodeUnicode(JSONObject.toJSONString(response.getData())));

            return Objects.equals(200, jsonObject.getInteger("code")) && Objects.equals("true", jsonObject.getString("status")) ?
                    DataVo.success(0, "汇鑫撞库成功", product.getPlanId())
                    : DataVo.fail(jsonObject.getString("msg"), product.getPlanId());
        } catch (Exception e) {
            log.error("汇鑫撞库失败", e);
            return DataVo.fail(1, "汇鑫撞库失败，请联系系统管理员", product.getPlanId());
        }

    }
    /**
     * unicode转汉字
     *
     * @param @param  theString
     * @param @return 设定文件
     * @return String 返回类型
     * @throws
     * @Title: decodeUnicode
     * @Description:
     */
    public static String decodeUnicode(String theString) {
        char aChar;
        int len = theString.length();
        StringBuffer outBuffer = new StringBuffer(len);
        for (int x = 0; x < len; ) {
            aChar = theString.charAt(x++);
            if (aChar == '\\') {
                aChar = theString.charAt(x++);
                if (aChar == 'u') {
                    int value = 0;
                    for (int i = 0; i < 4; i++) {
                        aChar = theString.charAt(x++);
                        switch (aChar) {
                            case '0':
                            case '1':
                            case '2':
                            case '3':
                            case '4':
                            case '5':
                            case '6':
                            case '7':
                            case '8':
                            case '9':
                                value = (value << 4) + aChar - '0';
                                break;
                            case 'a':
                            case 'b':
                            case 'c':
                            case 'd':
                            case 'e':
                            case 'f':
                                value = (value << 4) + 10 + aChar - 'a';
                                break;
                            case 'A':
                            case 'B':
                            case 'C':
                            case 'D':
                            case 'E':
                            case 'F':
                                value = (value << 4) + 10 + aChar - 'A';
                                break;
                            default:
                                throw new IllegalArgumentException(
                                        "Malformed      encoding.");
                        }

                    }
                    outBuffer.append((char) value);
                } else {
                    if (aChar == 't') {
                        aChar = '\t';
                    } else if (aChar == 'r') {
                        aChar = '\r';
                    } else if (aChar == 'n') {
                        aChar = '\n';
                    } else if (aChar == 'f') {
                        aChar = '\f';
                    }
                    outBuffer.append(aChar);
                }
            } else {
                outBuffer.append(aChar);
            }

        }
        return outBuffer.toString();

    }
}
