package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

/**
 * 捷诚API接单
 */
@Service
@Slf4j
public class JiechengCreditService implements LoanDockingApi {
    private final String qualityCheckPath = "/api/yrh/index";
    private final String applyPath = "/api/yrh/orderadd";


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.Jiecheng;
    }

    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *  {"key":"5lvNIA1Kmchq2gu3C9P5g+rttvQXq3lh","url":"http://www.cs.ahaiyu.com"}
     */
    @Override
        public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit JiechengCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
//            XdProductJointConfig xdProductJointConfig = xdProductJointConfigMapper.selectById(product.getJointType());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("捷诚对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setPhoneMd5(userInfo.getUserMobileMD5());
            String url = config.getString("url") + qualityCheckPath;
            log.info("credit qualityCheck JiechengCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            HttpApiResponse response = null;
            try{
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(String.valueOf(checkInfo),"post",url));
                response =httpClientFunc.apply(request);
            }catch (Exception e){
                log.error("捷诚准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck JiechengCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());
            return jsonObject.getInteger("code") == 200 && response.getData().equals("1") ? DataVo.success(0, "捷诚撞库成功", product.getPlanId())
                    : DataVo.fail("捷诚撞库失败:" + jsonObject.getInteger("message"), product.getPlanId());

        } catch (Exception e) {
            log.error("捷诚撞库失败", e);
            return DataVo.fail(1, "捷诚撞库失败，请联系系统管理员", product.getPlanId());
        }

    }


    @Data
    private static class CheckInfo{
        private String phoneMd5;
    }

    @Data
    private static class ResultJc{
        private int code;
        private String message;
        private String data;
    }


}
