package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

/**
 * 锦蝶API接单
 */
@Service
@Slf4j
public class JindieCreditService implements LoanDockingApi {
    private final String qualityCheckPath = "/erp/api/ifRepeatmd5";
    private final String applyPath = "/erp/api/addclue";


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.Jindie;
    }

    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return {"url":"https://jyw.jinchen.cc","Appid":"zZyeD3+kkEQVRWno","Appkey":"y52RC3muwUdtOhWe1Z0qo8FlFA","Channel":"网络渠道","ChannelInfo":"融5"}
     */
    @Override
         public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit JindieCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
//            XdProductJointConfig xdProductJointConfig = xdProductJointConfigMapper.selectById(product.getJointType());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("锦蝶对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();

            checkInfo.setAppid(config.getString("Appid"));
            checkInfo.setAppkey(config.getString("Appkey"));
            checkInfo.setUserphone(userInfo.getUserMobileMD5());
            String url = config.getString("url") + qualityCheckPath;
            log.info("credit qualityCheck JindieCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            HttpApiResponse response = null;
            try{
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(JSON.toJSONString(checkInfo),"post",url));
                response =httpClientFunc.apply(request);
            }catch (Exception e) {
                log.error("锦蝶准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck JindieCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());
            if (jsonObject.getInteger("result") == 400 ) {
                return DataVo.success(0, "锦蝶撞库成功", product.getPlanId());
            } else {
                return DataVo.fail("锦蝶撞库失败", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("锦蝶撞库失败", e);
            return DataVo.fail(1, "锦蝶撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

    @Data
    private static class CheckInfo {
        private String Appid;

        private String Appkey;

        private String Userphone;
    }

}
