package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * @Author Liu Tao
 * @Date 2024 06 27 14 06
 **/
@Slf4j
@Service
public class JiuXinKeCreditService implements LoanDockingApi {



    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.JiuXinKe;
    }

    @Data
    private static class CheckInfo {
        private String phoneMd5;// Md5(mobile)
        private Integer file_id;//渠道id
        private String promotion;//渠道标识
    }



    /**
     * 助贷对接撞库模板1,标准流程,post请求,application/json,参数直接传对象
     * @param userInfo
     * @param product
     * @return
     */
    @Override
         public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit JiuXinKeCreditService qualityCheck begin...userId:{}",userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("玖欣客对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            String url = config.getString("checkUrl");
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setPhoneMd5(phoneMd5);
            checkInfo.setPromotion(config.getString("promotion"));
            checkInfo.setFile_id(config.getInteger("file_id"));
            log.info("credit qualityCheck JiuXinKeCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            HttpApiResponse response = null;
            try{
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(JSON.toJSONString(checkInfo),"post",url));
                response =httpClientFunc.apply(request);
            }catch (Exception e) {
                log.error("玖欣客准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck JiuXinKeCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
              JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getString("code").equals("0")) {
                return DataVo.success(0, "玖欣客撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "玖欣客撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("玖欣客撞库失败", e);
            return DataVo.fail(1, "玖欣客撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

}
