package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

/**
 * 快易贷API接单
 */
@Service
@Slf4j
public class KuaiyidaiV2CreditService implements LoanDockingApi {



    private final String qualityCheckPath = "/Admin/UserIncomeApi/comparePhoneMonitor";

    private final String applyPath = "/Admin/UserIncomeApi/addUserAes";


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.KuaiyidaiV2;
    }

    @Data
    public static class CheckData{
        private String merNo;
        private String params;
    }

    @Data
    private static class ResultHt{
        private String status;
        private String mes;
    }

    @Data
    private static class ApplyResultHt{
        private Integer code;
        private String message;
    }

    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *  {"channelSource":"birong","url":"http://apitest.shlyxxjs.com","key":"mgjr@3des123#dhjr9763089"}
     */
    @Override
         public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit KuaiyidaiCreditService qualityCheck begin...userId:{}",userInfo.getUserId());

            String configJson = HessianUtils.deserialize(configInfo.getRequestConfig()).toString();
            JSONObject kuaiyidaiJointDTO = JSON.parseObject(configJson);
            log.info("快易贷对接参数:{}", JSON.toJSONString(kuaiyidaiJointDTO));

            Map<String, String> paramMap = new HashMap<>();
            paramMap.put("city",userInfo.getCityAllName() );
            paramMap.put("phone", userInfo.getUserMobileMD5());
            paramMap.put("qdName", kuaiyidaiJointDTO.getString("qdName"));


            String url = kuaiyidaiJointDTO.getString("url");
            log.info("credit qualityCheck KuaiyidaiCreditService request userId:{}, url:{}, data:{}",userInfo.getUserId(), url, JSON.toJSONString(paramMap));
            HttpApiResponse response = null;
            try{
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(String.valueOf(paramMap),"post",url));
                response =httpClientFunc.apply(request);
            }catch (Exception e){
                log.error("快易贷准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck KuaiyidaiCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return  DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());
            return Objects.equals("200",jsonObject.getString("status")) ? DataVo.success(0, "快易贷撞库成功", product.getPlanId())
                    : DataVo.fail(jsonObject.getString("mes"), product.getPlanId());
        } catch (Exception e) {
            log.error("快易贷撞库失败", e);
            return DataVo.fail(1, "快易贷撞库失败，请联系系统管理员", product.getPlanId());
        }

    }


}
