package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HeadsUtil;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

/**
 * @Author Liu Tao
 * @Date 2023 10 20 10 46
 * 昆明小松鼠API
 **/
@Slf4j
@Service
public class KunMingXiaoSongShuCreditService implements LoanDockingApi {



    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.KunMingXiaoSongShu;
    }

    @Data
    private static class CheckInfo{
        private String md5CusPhone;//md5 的手机号小写
    }

    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     */
    @Override
         public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit KunMingXiaoSongShuCreditService qualityCheck begin...userId:{}",userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("昆明小松鼠代对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setMd5CusPhone(phoneMd5);
            String url = config.getString("checkUrl")+"/"+checkInfo.getMd5CusPhone();
            log.info("credit qualityCheck KunMingXiaoSongShuCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            HttpApiResponse response = null;
            try{
//                Map<String, String> head = new HashMap<>();
//                head.put("Content-Type", "application/json; charset=utf-8");
//                head.put("access-control-allow-origin","*");
//                String httpResponse =  httpRestTemplate.restTemplate().getForObject(url, String.class,  head);
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(null,"post",url, HeadsUtil.getJsonHeaders("access-control-allow-origin","*")));
                response =httpClientFunc.apply(request);
                log.info("昆明小松鼠撞库响应数据：{}", response);
//                response = JSON.parseObject(httpResponse);
            }catch (Exception e){
                log.error("昆明小松鼠代准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck KunMingXiaoSongShuCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());
            if (jsonObject.getInteger("Code") == 1  && jsonObject.getString("Data").equals("false")) {
                return DataVo.success(0, "昆明小松鼠代撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "昆明小松鼠代撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("昆明小松鼠代撞库失败", e);
            return DataVo.fail(1, "昆明小松鼠代撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

}
