package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
/**
 * @Author Liu Tao
 * @Date 2024 07 18 14 51
 **/
@Slf4j
@Service
public class LeXiangRongCreditService implements LoanDockingApi {



    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.LeXiangRong;
    }

    @Data
    private static class CheckInfo{
        private String phone;//MD5加密
    }



    @Override
         public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit LeXiangRongCreditService qualityCheck begin...userId:{}",userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("乐享融对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setPhone(phoneMd5);
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck LeXiangRongCreditService request userId:{}, url:{}, checkInfo:{}",userInfo.getUserId(), url, checkInfo);
            HttpApiResponse response = null;
            try{
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(JSON.toJSONString(checkInfo),"post",url));
                response =httpClientFunc.apply(request);
            }catch (Exception e){
                log.error("乐享融准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck LeXiangRongCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
             JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());

            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getString("state").equals("200")) {
                return DataVo.success(0, "乐享融撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "乐享融撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("乐享融撞库失败", e);
            return DataVo.fail(1, "乐享融撞库失败，请联系系统管理员", product.getPlanId());
        }

    }


}
