package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import com.hrsk.cloud.eg.domain.common.RSAUtils;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.security.interfaces.RSAPublicKey;
import java.util.concurrent.TimeUnit;

/**
 * @Author Liu Tao
 * @Date 2024 04 12 09 29
 **/
@Slf4j
@Service
public class NanTongXingChengCreditService implements LoanDockingApi {




    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.NanTongXingChengCreditService;
    }

    @Data
    private static class CheckInfo{
        private String openId;//广告平台
        private String cityCode;//城市代码
        private String phone;
    }
    @Data
    private static class Request{
        private String data;
    }




    @Override
         public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit NanTongXingChengCreditService qualityCheck begin...userId:{}",userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("南通星辰对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setPhone(phoneMd5);
            checkInfo.setOpenId(config.getString("openId"));
            String cityCode = String.valueOf(userInfo.getCityCode());
            String citycodes=cityCode+"000000";
            checkInfo.setCityCode(citycodes);
            RSAPublicKey publicKey = RSAUtils.getPublicKey(config.getString("key"));
            String data = RSAUtils.publicEncrypt(JSON.toJSONString(checkInfo), publicKey);
            Request request= new Request();
            request.setData(data);
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck NanTongXingChengCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, phoneMd5);
            HttpApiResponse response = null;
            try{
                HttpApiRequest request2=new HttpApiRequest(HttpApiRequestConfig.postRequest(String.valueOf(request),"post",url));
                response =httpClientFunc.apply(request2);
            }catch (Exception e){
                log.error("南通星辰准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck NanTongXingChengCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
             JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getString("result").equals("true")) {
                RedisSetDto redisSetDto=new RedisSetDto();
                redisSetDto.setKey(String.format("zudai:token:%s:%s", "nantong", phoneMd5));
                redisSetDto.setValue(jsonObject.getString("token"));
                redisSetDto.setTime(1);
                redisSetDto.setTimeUnit(TimeUnit.DAYS);
                redisSetFunction.apply(redisSetDto);
               return DataVo.success(0, "南通星辰撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "南通星辰撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("南通星辰撞库失败", e);
            return DataVo.fail(1, "南通星辰撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

}
