package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import java.util.Objects;

/**
 * @Descrption
 * @Author: chend
 * @Date: 2023/2/27
 * @Version V1.0
 **/
@Slf4j
@Service
public class OpenApiCreditService implements LoanDockingApi {



    private final static String IV="go9yPim47avSQZ8m";


    @Data
    private static class CheckInfo {
        private String channelCode = "hrsk";

        private String city;

        private String phoneMd5;
    }

    @Data
    private static class Result {
        private Integer code;
        private String msg;
        private JSONObject data;
    }



    @Override
         public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction) {
        log.info("credit OpenApiCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
        try {
            String config = HessianUtils.deserialize(configInfo.getRequestConfig()).toString();
            JSONObject jsonObject = JSONObject.parseObject(config);
            if (StringUtils.isAnyEmpty(jsonObject.getString("openapiCheckUrl"), jsonObject.getString("openapiAccessKeySecret"))) {
                return DataVo.fail(product.getPlanName(), product.getPlanId());
            }
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setPhoneMd5(userInfo.getUserMobileMD5());
            checkInfo.setCity(userInfo.getCompanyCity());
            String url = jsonObject.getString("openapiCheckUrl");
            log.info("credit qualityCheck OpenApiCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            HttpApiResponse response = null;
            try {
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(String.valueOf(checkInfo),"post",url));
                response =httpClientFunc.apply(request);
            } catch (Exception e) {
                log.error("OpenAPI准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck OpenApiCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject2=JSONObject.parseObject(response.getData().toString());
            String data = jsonObject2.getString("data");
            JSONObject jsonObject1 = JSONObject.parseObject(data);
            return Objects.equals(0, jsonObject2.getInteger("code")) && Objects.equals(0, jsonObject1.getInteger("status")) ?
                    DataVo.success(0, "OpenAPI撞库成功", product.getPlanId())
                    : DataVo.fail(jsonObject2.getString("msg"), product.getPlanId());

        } catch (Exception e) {
            log.error("OpenAPI撞库失败", e);
            return DataVo.fail(1, "OpenAPI撞库失败，请联系系统管理员", product.getPlanId());
        }
    }


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.OPEN_API;
    }

}
