package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;

import javax.annotation.Resource;

/**
 * @Author zjc
 * @Date 2024 07 17 14 53
 **/
@Slf4j
@Component
public class QingDaoAoSengV2CreditService implements LoanDockingApi {

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.QingDaoAoSenV2;
    }

    @Data
    private static class CheckInfo{
        private String code;
    }


    @Override
        public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
//            log.info("credit YunHaiLianDongCreditService qualityCheck begin...userId:{}", userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());

            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setCode((userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5()));

            String url = config.getString("checkUrl");
//            log.info("credit qualityCheck YunHaiLianDongCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            HttpApiResponse response = null;
            try {
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(String.valueOf(checkInfo),"post",url));
                response =httpClientFunc.apply(request);
            } catch (Exception e) {
                log.error("青岛奥森V2准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck QingDaoAoSenV2CreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
              JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());
//            log.info("credit qualityCheck YunHaiLianDongCreditService response userId:{}, jsonObject:{}", userInfo.getUserId(), jsonObject);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("code") == 1) {
                return DataVo.success(0, "青岛奥森V2撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "青岛奥森V2撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("青岛奥森撞库失败", e);
            return DataVo.fail(1, "青岛奥森V2撞库失败，请联系系统管理员", product.getPlanId());
        }
    }
}
