package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HeadsUtil;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cglib.beans.BeanMap;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.*;

/**
 * @Author Liu Tao
 * @Date 2023 09 06 15 31
 **/
@Component
@Slf4j
public class QingyuV3CreditService implements LoanDockingApi {

    @Override
    public ServerCodeEnums  getType() {
        return ServerCodeEnums.CRM_QY_V3;
    }

    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return {
     * 	"checkUrl": "http://36.111.70.93:804/qingyu3/access/phoneMd5Check",
     * 	"applyUrl": "http://36.111.70.93:804/qingyu3/access/customer",
     * 	"accessKey": "b71df3c8aff86fbd46b732a183e2d34c",
     * 	"source": "中融闪贷",
     * 	"publicKey": "MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQCjlJ/w9nHYEAJKseVHonypwWy1bDb0+8XXfPB9NSsgZxS8aLJVH2RqRNeKQNghDT+yg+YEst16XVlBng+o+4id0XT18vmoXBSfys7lImv7FMJiZx2Kac6lYrmoLmgJT3Dg4MQ10RApkPWKhRowicY9VPdlUSj8G1TEdwuhVe/ljwIDAQAB"
     * }
     */
    @Override
         public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction) {
        try {
            log.info("credit QingyuV3CreditService qualityCheck begin...userId:{},productId={}", userInfo.getUserId(), product.getPlanName());
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("庆鱼V3.0对接参数:{}", JSON.toJSONString(config));
            V3Req checkInfo = new V3Req();
            checkInfo.setAccessKey(config.getString("accessKey"));
            checkInfo.setRequestId(UUID.randomUUID().toString());

            JSONObject jsonObject = new JSONObject() {{
                put("phone", userInfo.getUserMobileMD5());
            }};
            JSONArray dataArray = new JSONArray();
            dataArray.add(jsonObject);
            checkInfo.setData(dataArray);
            String checkUrl = config.getString("checkUrl");

            log.info("credit qualityCheck QingyuV3CreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), checkUrl, checkInfo);
            HttpApiResponse response = null;
            try {
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(String.valueOf(checkInfo),"post",checkUrl));
                response =httpClientFunc.apply(request);
            } catch (Exception e) {
                log.error("【{}】-庆鱼V3.0准入异常,异常信息：{}", product.getPlanName(), e.getMessage(), e);
            }
            log.info("credit qualityCheck QingyuV3CreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject1=JSONObject.parseObject(response.getData().toString());
            if (jsonObject1.getInteger("code") == 200 && jsonObject1.getBoolean("success") && jsonObject1.getJSONArray("data").size() == 0) {
                return DataVo.success(0, "【" + product.getPlanName() + "】-庆鱼V3.0撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(jsonObject1.getString("msg"), product.getPlanId());
            }
        } catch (Exception e) {
            log.error("【{}】-庆鱼V3.0撞库失败", product.getPlanName(), e);
            return DataVo.fail(1, "庆鱼V3.0撞库失败，请联系系统管理员", product.getPlanName());
        }

    }
    public static <T> Map<String, Object> beanToMap(T bean) {
        Map<String, Object> map = new HashMap<>();
        if (bean != null) {
            BeanMap beanMap = BeanMap.create(bean);
            for (Object key : beanMap.keySet()) {
                map.put(key + "", beanMap.get(key));
            }
        }
        return map;
    }


    private String getSign(Map<String, Object> map) {
        String text = "";
        Iterator<Map.Entry<String, Object>> iterator = map.entrySet().iterator();
        while (iterator.hasNext()) {
            Map.Entry<String, Object> entry = iterator.next();
            String value;
            if (null == entry.getValue()) {
                value = "";
            } else {
                value = (String) entry.getValue();
            }
            text = text + entry.getKey() + value;
        }
        return Md5Util.encoderByMd5(text).toUpperCase();
    }


    @Data
    private static class V3Req {
        private String requestId;

        private String accessKey;

        private JSONArray data;
    }

    @Data
    private static class CheckInfoResp {
        private Integer code;
        private String msg;
        private Boolean success;
        private List<JSONObject> data;
    }


}

