package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.DateUtil;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import java.nio.charset.StandardCharsets;
import java.util.Base64;
import java.util.Date;

/**
 * @Author Liu Tao
 * @Date 2024 06 18 11 35
 **/
@Slf4j
@Service
public class RongYiDaCreditService implements LoanDockingApi {




    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.RongYiDa;
    }

    //撞库
    @Data
    private static class CheckInfo {
        private String phoneNo;//md5 的手机号

    }

    @Data
    private static class RquestParam {
        private String data;
        private String merchantNo;
        private String timestamp;
        private String reqId;

    }


    @Override
         public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit RongYiDaCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("融易达对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setPhoneNo(phoneMd5);
            RquestParam requestParam=new RquestParam();
            requestParam.setTimestamp(DateUtil.getFormatDate(new Date(), "yyyy-MM-dd HH:mm:ss"));
            requestParam.setData(encrypt( config.getString("key"),config.getString("iv"),JSON.toJSONString(checkInfo)));
            requestParam.setReqId(config.getString("reqId"));
            requestParam.setMerchantNo(config.getString("merchantNo"));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck RongYiDaCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, phoneMd5);
            HttpApiResponse response = null;
            try {
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(JSON.toJSONString(requestParam),"post",url));
                response =httpClientFunc.apply(request);
            } catch (Exception e) {
                log.error("融易达准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck RongYiDaCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
              JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getString("dealStatus").equals("0000")) {
                return DataVo.success(0, "融易达撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "融易达撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("融易达撞库失败", e);
            return DataVo.fail(1, "融易达撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

    public static String encrypt(String key, String initVector, String value) throws Exception {
        IvParameterSpec iv = new IvParameterSpec(initVector.getBytes(StandardCharsets.UTF_8));
        SecretKeySpec skeySpec = new SecretKeySpec(key.getBytes(StandardCharsets.UTF_8), "AES");

        Cipher cipher = Cipher.getInstance("AES/CBC/PKCS5PADDING");
        cipher.init(Cipher.ENCRYPT_MODE, skeySpec, iv);

        byte[] encrypted = cipher.doFinal(value.getBytes());
        return Base64.getEncoder().encodeToString(encrypted);
    }

    public static String decrypt(String key, String initVector, String encrypted) throws Exception {
        IvParameterSpec iv = new IvParameterSpec(initVector.getBytes(StandardCharsets.UTF_8));
        SecretKeySpec skeySpec = new SecretKeySpec(key.getBytes(StandardCharsets.UTF_8), "AES");

        Cipher cipher = Cipher.getInstance("AES/CBC/PKCS5PADDING");
        cipher.init(Cipher.DECRYPT_MODE, skeySpec, iv);

        byte[] original = cipher.doFinal(Base64.getDecoder().decode(encrypted));

        return new String(original);
    }
}
