package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HeadsUtil;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Hex;

import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.*;

/**
 * 荣西子API接单
 */
@Service
@Slf4j
public class RongxiziCreditService implements LoanDockingApi {


    private final String qualityCheckPath = "https://admin.qxd-wh.com/home/Api/checkTel";

    private final String applyPath = "http://47.111.167.41:8009/customer/import";



    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.Rongxizi;
    }


    @Data
    private static class ResultHt{
        private String code;
        private String msg;
    }
    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     * {"token":"UWDSdzJHCq3KnrLwuBaPBBGX8Hs0oEY3","vender_name":"birong","appid":"20076","appkey":"05xduuQdn6r46giJji91aXDlzEeOT5Be"}
     */
    @Override
        public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit RongxiziCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
//            XdProductJointConfig xdProductJointConfig = xdProductJointConfigMapper.selectById(product.getJointType());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("荣西子对接参数:{}", JSONObject.toJSONString(config));
            String url = qualityCheckPath;
            log.info("credit qualityCheck RongxiziCreditService request userId:{}, url:{}",userInfo.getUserId(), url);

            Map map = new HashMap();
            map.put("token",config.getString("token"));
            map.put("tel",userInfo.getUserMobileMD5());

            HttpApiResponse response = null;
            try{
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(String.valueOf(map),"post",url, HeadsUtil.getFromHeaders(null,null)));
                response =httpClientFunc.apply(request);

            }catch (Exception e){
                log.error("荣西子准入异常,异常信息：{}", e.getMessage(), e);
            }
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject result = JSONObject.parseObject(response.getData().toString());
            log.info("credit qualityCheck RongxiziCreditService response userId:{}, result:{}",userInfo.getUserId(), JSONObject.toJSONString(result));
            if (result.getInteger("code") == 200) {
                if (result.getJSONObject("data").getInteger("state") == 0 ) {
                    return DataVo.success(0, "荣西子撞库成功", product.getPlanId());
                }
            }
            return DataVo.fail(1, result.getString("message"), product.getPlanId());

        } catch (Exception e) {
            log.error("荣西子撞库失败", e);
            return DataVo.fail(1, "荣西子撞库失败，请联系系统管理员", product.getPlanId());
        }

    }


    private static String buildPreSign(Map map){

        //将参数转换为map

        Set<String> keys = map.keySet();
        List<String> list = new ArrayList<>();
        for (String key : keys) {
            if(!StringUtils.isEmpty(map.get(key))){
                list.add(key);
            }
        }
        //排序key
        Collections.sort(list);
        //遍历封装排序后key的list,拼接字符串
        StringBuilder sb = new StringBuilder("");
        for (int i=0;i<list.size();i++) {
            if (i==0){
                sb.append(list.get(i)).append("=").append(map.get(list.get(i)));
            }else {
                sb.append("&");
                sb.append(list.get(i)).append("=").append(map.get(list.get(i)));
            }

        }
        return sb.toString();
    }

    private static String sha1(String text){

        // 获取指定摘要算法的messageDigest对象
        MessageDigest messageDigest = null; // 此处的sha代表sha1
        try {
            messageDigest = MessageDigest.getInstance("SHA");
        } catch (NoSuchAlgorithmException e) {
            e.printStackTrace();
        }

        // 调用digest方法，进行加密操作
        byte[] cipherBytes = messageDigest.digest(text.getBytes());

        return Hex.encodeHexString(cipherBytes);
    }
}
