package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Objects;

/**
 * @Descrption
 * @Author: chend
 * @Date: 2023/4/17
 * @Version V1.0
 **/
@Slf4j
@Service
public class RxkCreditService implements LoanDockingApi {
    private final static String CHECK_URL="/xxb-filter/api/filter/md5";
    private final static String REGISTER_URL="/xxb/api/source/clue_data/consumer";


    private final static String CHECK_URL_PRIVATE="/youka/api/user_filter/md5";
    private final static String REGISTER_URL_PRIVATE="/youka/api/clue_data/accept";


    @Data
    private static class CheckInfo {
        private String sourceCode;

        private String accessKey;

        private String phoneMd5;
    }

    @Data
    private static class Result {
        private Integer code;
        private String msg;
        private JSONObject data;
        private boolean success;
    }

    @Data
    private static class ResultRegister {
        private String code;
        private String msg;
        private String data;
        private boolean success;
    }



    @Override
         public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction) {
        log.info("credit RxkCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
        try {
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("融享客对接参数:{}", JSON.toJSONString(config));

            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setPhoneMd5(userInfo.getUserMobileMD5());
            checkInfo.setSourceCode(config.getString("sourceCode"));
            checkInfo.setAccessKey(config.getString("accessKey"));
            String url;
            if(null !=config.get("private") && config.getBoolean("private")){
                url = config.getString("domain")+CHECK_URL_PRIVATE;
            }else {
                url = config.getString("domain")+CHECK_URL;
            }
            log.info("credit qualityCheck RxkCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            HttpApiResponse response = null;
            try {
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(JSON.toJSONString(checkInfo),"post",url));
                response =httpClientFunc.apply(request);
            } catch (Exception e) {
                log.error("融享客准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck RxkCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());
            return
                    Objects.equals(1, jsonObject.getInteger("code"))
                            && Objects.equals(true,jsonObject.getBoolean("isSuccess"))
                            && Objects.equals(false, jsonObject.getBoolean("phoneMd5Exist")) ?
                            DataVo.success(0, "融享客撞库成功", product.getPlanId())
                            : DataVo.fail("融享客-"+product.getPlanName()+"撞库失败", product.getPlanId());

        } catch (Exception e) {
            log.error("融享客撞库失败", e);
            return DataVo.fail(1, "融享客撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.CRM_RXK;
    }

}
