package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HeadsUtil;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;

import javax.annotation.Resource;

/**
 * @Author Liu Tao
 * @Date 2024 06 05 14 46
 **/
@Slf4j
@Component
public class ShangHaiHanGeCreditService implements LoanDockingApi {
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.ShangHaiHanGe;
    }

    @Data
    private static class CheckInfo {
        private String MobilePhone;// 手机号（32位MD5加密字符串）
    }



    @Override
         public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("上海晗各对接参数:{}", JSONObject.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            String url = config.getString("checkUrl");
            log.info("上海晗各开始撞库,请求地址：{},md5:{}", url, phoneMd5);
            MultiValueMap<String, String> params= new LinkedMultiValueMap<String, String>();
            params.add("MobilePhone", phoneMd5);
            HttpApiResponse response = null;
            try{
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(String.valueOf(params),"post",url, HeadsUtil.getFromHeaders(null,null)));
                response =httpClientFunc.apply(request);
            } catch (Exception e) {
                log.error("上海晗各准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("上海晗各撞库响应：{},md5:{}", response, phoneMd5);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
              JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());
            if (jsonObject.getString("Ret").equals("0")&&jsonObject.getString("Code").equals("100")) {
                return DataVo.success(0, "上海晗各撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "上海晗各撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            return DataVo.fail(1, "上海晗各撞库失败，请联系系统管理员", product.getPlanId());
        }
    }


}
