package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HeadsUtil;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;

import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;

/**
 * @Author Liu Tao
 * @Date 2024 07 17 15 21
 **/
@Slf4j
@Component
public class ShenLuoJinFuCreditService implements LoanDockingApi {
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.ShenLuoJinFu;
    }

    @Data
    private static class CheckInfo{
        private String account_key;//account_key值需接口方提供
        private String tel_m;//手机号（MD5加密的32位小写）
        private String city;//城市，例如（上海或上海市）
        private String repeat_system;//指定系统撞库（需接口方提供）
    }




    @Override
         public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("盛略金服对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            Map<String, String> requestData = new HashMap<>();
            requestData.put("tel_m", phoneMd5);
            requestData.put("account_key", config.getString("account_key"));
            requestData.put("city",userInfo.getCityAllName());
            if (config.getString("repeat_system")!=null){
                requestData.put("repeat_system", config.getString("repeat_system"));
            }
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck ShenLuoJinFuCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            HttpApiResponse response = null;
            try{
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(String.valueOf(requestData),"post",url, HeadsUtil.getFromHeaders(null,null)));
                response =httpClientFunc.apply(request);
            }catch (Exception e){
                log.error("盛略金服准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck ShenLuoJinFuCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject result=JSONObject.parseObject(response.getData().toString());
            if (result.getInteger("code")==1) {
                return DataVo.success(0, "盛略金服撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "盛略金服撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("盛略金服撞库失败", e);
            return DataVo.fail(1, "盛略金服撞库失败，请联系系统管理员", product.getPlanId());
        }

    }


}
