package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * @Author zjc
 * @Date 2024 07 09 16 36
 **/
@Slf4j
@Service
public class SuZhouJianYiRongCreditService implements LoanDockingApi {
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.SuZhouJianYiRong;
    }

    @Data
    private static class CheckInfo{
        private String md5_mobile;//md5加密后的手机号，32位小写
    }


    @Data
    private static class RquestParam {
        private String source;//渠道来源
        private String file_id;//
        private String data;//	AES加密 (AES/ECB/PKCS5Padding)
        private String sign;
        private String timestamp;


    }
    @Override
         public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit SuZhouJianYiRongCreditService qualityCheck begin...userId:{}",userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("苏州简易融对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setMd5_mobile(phoneMd5);


            String url = config.getString("checkUrl");

            log.info("credit qualityCheck SuZhouJianYiRongCreditService request userId:{}, url:{}, checkInfo:{}",userInfo.getUserId(), url, checkInfo);
            HttpApiResponse response = null;
            try{
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(JSON.toJSONString(checkInfo),"post",url));
                response =httpClientFunc.apply(request);
            }catch (Exception e){
                log.error("苏州简易融准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck SuZhouJianYiRongCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
             JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());

            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("code") ==0 ) {
                return DataVo.success(0, "苏州简易融撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "苏州简易融撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("苏州简易融撞库失败", e);
            return DataVo.fail(1, "苏州简易融撞库失败，请联系系统管理员", product.getPlanId());
        }

    }



}
