package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * @Author Liu Tao
 * @Date 2023 12 13 16 07
 **/
@Slf4j
@Service
public class TianShuiShuYiRongCreditService implements LoanDockingApi {


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.TianShuiShuYiRong;
    }


    @Override
         public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit TianShuiShuYiRongCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("天水速易融对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            String checkUrl = config.getString("checkUrl");
            String company = config.getString("company");
            String url = checkUrl + "?company=" + company + "&mobile_md5=" + phoneMd5;
            log.info("credit qualityCheck TianShuiShuYiRongCreditService request userId:{}, url:{}, phoneMd5:{}", userInfo.getUserId(), url, phoneMd5);
            HttpApiResponse response = null;
            try{
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(null,"post",url));
                response =httpClientFunc.apply(request);
            } catch (Exception e) {
                log.error("天水速易融准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck TianShuiShuYiRongCreditService response userId:{}, result:{}", userInfo.getUserId(), response);

            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
              JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());
            if (jsonObject.getInteger("code") == 0) {
                return DataVo.success(0, "天水速易融撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "天水速易融撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("天水速易融撞库失败", e);
            return DataVo.fail(1, "天水速易融撞库失败，请联系系统管理员", product.getPlanId());
        }

    }


}
