package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HeadsUtil;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;

import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;


/**
 * @Author Liu Tao
 * @Date 2024 07 03 16 14
 **/
@Slf4j
@Service
public class WeiFangHuaShenCreditService implements LoanDockingApi {




    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.WeiFangHuaShenCreditService;
    }

    @Data
    private static class CheckInfo{
        private Integer channel_code;//渠道编码，由负责人提供
        private String md5_phone;//md5加密后的手机号，32位小写
    }



    /**
     * 助贷对接模板2，撞库，需要form表单提交
     * @param userInfo
     * @param product
     * @return
     */
    @Override
         public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit WeiFangHuaShenCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("潍坊华盛对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setMd5_phone(phoneMd5);
            checkInfo.setChannel_code(config.getInteger("channel_code"));

            Map<String, String> requestData = new HashMap<>();
            requestData.put("channel_code", String.valueOf(checkInfo.getChannel_code()));
            requestData.put("md5_phone", String.valueOf(checkInfo.getMd5_phone()));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck WeiFangHuaShenCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            HttpApiResponse response = null;
            try{
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(String.valueOf(requestData),"post",url, HeadsUtil.getFromHeaders(null,null)));
                response =httpClientFunc.apply(request);
            }catch (Exception e){
                log.error("潍坊华盛准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck WeiFangHuaShenCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject result=JSONObject.parseObject(response.getData().toString());
            if (result.getInteger("code")==0) {
                return DataVo.success(0, "潍坊华盛撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "潍坊华盛撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("潍坊华盛撞库失败", e);
            return DataVo.fail(1, "潍坊华盛撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

}
