package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;

import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.KeyValueObject;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.ValueObjectTypeEnum;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Base64;

import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.spec.SecretKeySpec;
import java.util.ArrayList;
import java.util.List;

/**
 * @Author Liu Tao
 * @Date 2023 12 04 14 51
 **/
@Slf4j
@Service
public class XiaoMeiYiRongCreditService implements LoanDockingApi {


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.XiaoMeiYiRong;
    }

    @Data
    private static class RequestDate {
        private String data;
        private Integer providerAPIId;
        private Integer encryptType;
    }
    @Data
    private static class CheckInfo {
        private String telMD5;
    }
    @Override
         public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit XiaoMeiYiRongCreditService qualityCheck begin...userId:{}", userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("小美易融对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo=new CheckInfo();
            checkInfo.setTelMD5( userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5());
            RequestDate requestDate=new RequestDate();
            requestDate.setData(AESUtil.encrypt(JSON.toJSONString(checkInfo),config.getString("publicKey")));
            requestDate.setProviderAPIId(config.getInteger("apiId"));
            requestDate.setEncryptType(1);
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck XiaoMeiYiRongCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, requestDate);
          //  JsonNode jsonNode = null;
            HttpApiResponse response = null;
            try {

                //HttpHeaders headers = new HttpHeaders();
                List<KeyValueObject> header = new ArrayList<>();
                KeyValueObject keyValueObject0 = new KeyValueObject();
                keyValueObject0.setType(ValueObjectTypeEnum.BASIC.getType());
                keyValueObject0.setKey("Content-Type");
                keyValueObject0.setValue("application/json");
                KeyValueObject keyValueObject = new KeyValueObject();
                keyValueObject.setType(ValueObjectTypeEnum.BASIC.getType());
                keyValueObject.setKey("User-Agent");
                keyValueObject.setValue("Apifox/1.0.0 (https://apifox.com)");
                header.add(keyValueObject0);
                header.add(keyValueObject);
//                HttpEntity<String> requestEntity = new HttpEntity<>(JSONObject.toJSONString(checkInfo), headers);
//                httpRestTemplate.restTemplate().postForEntity(url, checkInfo, String.class);
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(String.valueOf(checkInfo),"post",url, header));
                response =httpClientFunc.apply(request);

//                String responseBody = requestEntity.getBody();
                log.info("小美易融 =======================>{}",response);
//                ObjectMapper objectMapper = new ObjectMapper();
//                // 解析JSON字符串
//                jsonNode = objectMapper.readTree(responseBody);
            } catch (Exception e) {
                log.error("小美易融准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck XiaoMeiYiRongCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());
            if (jsonObject.getInteger("code")==0) {
                return DataVo.success(0, "小美易融撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "小美易融撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("小美易融撞库失败", e);
            return DataVo.fail(1, "小美易融撞库失败，请联系系统管理员", product.getPlanId());
        }
    }



    public static class AESUtil {

        public static final String AES = "AES";

        private static final String ALGORITHMSTR = "AES/ECB/PKCS7Padding";


        /**
         * encrypt input text
         *
         * @param input
         * @param key
         * @return
         * @throws Exception
         */
        public static String encrypt(String input, String key) throws Exception {

            SecretKeySpec skey = new SecretKeySpec(key.getBytes(), AES);
            Cipher cipher = Cipher.getInstance(ALGORITHMSTR);
            cipher.init(Cipher.ENCRYPT_MODE, skey);
            byte[] crypted = cipher.doFinal(input.getBytes("UTF8"));

            return new String(Base64.encodeBase64(crypted));
        }
    }
}
