package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;
import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * @Author Liu Tao
 * @Date 2024 07 09 17 03
 **/
@Slf4j
@Service
public class XinChuangYinHuiCreditService implements LoanDockingApi {



    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.XinChuangYinHui;
    }

    @Data
    private static class CheckInfo {
        private String phoneMd5;// 手机号md5
        private String channelCode;//渠道编号
        private String city;//城市
    }

    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction) {
        try {
            log.info("credit XinChuangYinHuiCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("信创对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            JSONObject json = new JSONObject();
            json.put("phoneMd5", phoneMd5);
            json.put("channelCode", config.getString("channelCode"));
            json.put("city", userInfo.getCompanyCity());
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck XinChuangYinHuiCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, phoneMd5);
            HttpApiResponse response = null;
            try {
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(JSON.toJSONString(json),"post",url));
                response =httpClientFunc.apply(request);
            } catch (Exception e) {
                log.error("信创准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck XinChuangYinHuiCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
              JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());

            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject data = JSONObject.parseObject(jsonObject.getString("data"));
            if (jsonObject.getInteger("code") == 0 && data.getInteger("status") == 0) {
                return DataVo.success(0, "信创撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "信创撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("信创撞库失败", e);
            return DataVo.fail(1, "信创撞库失败，请联系系统管理员", product.getPlanId());
        }
    }


}
