package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HeadsUtil;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;

import javax.annotation.Resource;

/**
 * 欣客贷API接单
 */
@Service
@Slf4j
public class XinkedaiCreditService implements LoanDockingApi {
    private final String qualityCheckPath = "/admin/pushApi/check_mobile";
    private final String applyPath = "/admin/pushApi/import_tttg";
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.Xinkedai;
    }


    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *  {"url":"http://121.40.173.17:8811"}
     */
    @Override
         public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit XingkedaiCreditService qualityCheck begin...userId:{}",userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("欣客贷对接参数:{}", JSON.toJSONString(config));

            MultiValueMap<String, String> params= new LinkedMultiValueMap<String, String>();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            params.add("mobile", phoneMd5);
            String url = config.getString("url") + qualityCheckPath;
            log.info("credit qualityCheck XingkedaiCreditService request userId:{}, url:{}, params:{}",userInfo.getUserId(), url, JSON.toJSONString(params));

            HttpApiResponse response = null;
            try{
                    HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(String.valueOf(params),"post",url, HeadsUtil.getFromHeaders(null,null)));
                    response =httpClientFunc.apply(request);
            }catch (Exception e){
                log.error("欣客贷准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck XingkedaiCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject result=JSONObject.parseObject(response.getData().toString());
            if ( result.getInteger("statusCode")!= 200) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            return result.getInteger("code") ==0 ? DataVo.success(0, "欣客贷撞库成功", product.getPlanId())
                    : DataVo.fail("撞库失败", product.getPlanId());

        } catch (Exception e) {
            log.error("欣客贷撞库失败", e);
            return DataVo.fail(1, "欣客贷撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

}
