package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HeadsUtil;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

/**
 * 信易贷API接单
 */
@Service
@Slf4j
public class XinyidaiCreditService implements LoanDockingApi {


    private final String qualityCheckPath = "/api/customer/md5check";

    private final String applyPath = "/api/customer/add";
    @Value("${spring.profiles.active}")
    private String activeProfile;



    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.Xinyidai;
    }


    @Data
    public static class CheckData{
        private String mobile_md5;
        private String city;
    }

    @Data
    private static class CheckInfo{
        private String client_id;

        private String client_secret;

        private CheckData data;


    }
    @Data
    private static class ResultHt{
        private Integer code;
        private String message;
    }
    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *  {"channelSource":"birong","url":"http://apitest.shlyxxjs.com","key":"mgjr@3des123#dhjr9763089"}
     */
    @Override
         public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit XinyidaiCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
//            XdProductJointConfig xdProductJointConfig = xdProductJointConfigMapper.selectById(product.getJointType());
           
            String configJson = HessianUtils.deserialize(configInfo.getRequestConfig()).toString();
            JSONObject xinyidaiJointDTO = JSON.parseObject(configJson);
            log.info("信易贷对接参数:{}", JSON.toJSONString(xinyidaiJointDTO));
            String url = xinyidaiJointDTO.getString("url") + qualityCheckPath+"?md5=" +userInfo.getUserMobileMD5() ;
            log.info("credit qualityCheck XinyidaiCreditService request userId:{}, url:{}",userInfo.getUserId(), url);

            HttpApiResponse response = null;
            try{
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(null,"post",url, HeadsUtil.getFromHeaders(null,null)));
                response =httpClientFunc.apply(request);
            }catch (Exception e){
                log.error("信易贷准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck XinyidaiCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject result=JSONObject.parseObject(response.getData().toString());
            return Objects.equals(12, result.getInteger("code")) ? DataVo.success(0, "信易贷撞库成功", product.getPlanId())
                    : DataVo.fail(result.getString("message"), product.getPlanId());
        } catch (Exception e) {
            log.error("信易贷撞库失败", e);
            return DataVo.fail(1, "信易贷撞库失败，请联系系统管理员", product.getPlanId());
        }

    }
}
