package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;

import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.KeyValueObject;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.ValueObjectTypeEnum;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.UserUtils;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;

import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

/**
 * 雪易融 API 接单
 * @author 黄洋
 * @since 1.0
 */
@Slf4j
@Component
public class XveYiRongCreditService implements LoanDockingApi {


    @Data
    private static class Result {
        private Integer code;
        private String msg;
        private JSONObject data;
    }

    @Data
    private static class CheckInfo {
        /**
         * 手机号
         */
        private String name;
        /**
         * 手机号
         */
        private String phone;

    }

    /**
     * 撞库
     */
    @Override
         public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        log.info("credit XveYiRongCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
        try {

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            if (Objects.isNull(config)) {
                return DataVo.fail(product.getPlanName(), product.getPlanId());
            }
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setName(UserUtils.getUserName(userInfo.getRealName(), userInfo.getPoliceSex()));
            checkInfo.setPhone(userInfo.getUserMobileMD5());

            String url = config.getString("checkUrl");
            log.info("credit qualityCheck XveYiRongCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
//            JsonNode jsonNode = null;
//            String msg = null;
//            String data = null;
            HttpApiResponse response = null;
            try {
//                HttpHeaders headers = new HttpHeaders();
                List<KeyValueObject> header = new ArrayList<>();
                KeyValueObject keyValueObject0 = new KeyValueObject();
                keyValueObject0.setType(ValueObjectTypeEnum.BASIC.getType());
                keyValueObject0.setKey("Content-Type");
                keyValueObject0.setValue("text/plain");

                KeyValueObject keyValueObject = new KeyValueObject();
                keyValueObject.setType(ValueObjectTypeEnum.BASIC.getType());
                keyValueObject.setKey("authKey");
                keyValueObject.setValue(config.getString("authKey"));

                KeyValueObject keyValueObject2 = new KeyValueObject();
                keyValueObject2.setType(ValueObjectTypeEnum.BASIC.getType());
                keyValueObject2.setKey("sessionId");
                keyValueObject2.setValue(config.getString("sessionId"));


                header.add(keyValueObject0);
                header.add(keyValueObject);
                header.add(keyValueObject2);

                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(String.valueOf(checkInfo),"post",url, header));
                response =httpClientFunc.apply(request);


//                String responseBody = requestEntity.getBody();
//                log.info("雪易融 =======================>{}",JSONObject.parseObject(responseBody));
//                ObjectMapper objectMapper = new ObjectMapper();
//                // 解析JSON字符串
//                 jsonNode = objectMapper.readTree(responseBody);
//
//                if(!Objects.isNull(jsonNode.get("msg"))){
//                    msg = jsonNode.get("msg").asText();
//                }
//                if(!Objects.isNull(jsonNode.get("data"))){
//                    data = jsonNode.get("data").asText();
//                }


            } catch (Exception e) {
                log.error("雪易融准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck 雪易融CreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject result=JSONObject.parseObject(response.getData().toString());
            String msg=result.getString("msg");
            String data=response.getData().toString();
            return Objects.equals(0,  result.getInteger("code")) ?
                    DataVo.success(0, "雪易融撞库成功", product.getPlanId())
                    : DataVo.fail((msg != null) ? msg : data, product.getPlanId());

        } catch (Exception e) {
            log.error("雪易融撞库失败", e);
            return DataVo.fail(1, "雪易融撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.XveYiRong;
    }



}
