package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.KeyValueObject;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.ValueObjectTypeEnum;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Author Liu Tao
 * @Date 2024 06 13 14 50
 **/
@Slf4j
@Service
public class YiBangDaiCreditService implements LoanDockingApi {



    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.YiBangDaiCreditService;
    }
    @Data
    private static class CheckInfo{
        private String mobile;// 手机号md5
    }
    @Override
         public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit FuChengCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("壹帮贷对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            Map<String, String> requestData = new HashMap<>();
            requestData.put("mobile", phoneMd5);
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck FuChengCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, phoneMd5);
//            JSONObject response = null;
            HttpApiResponse response = null;
            try{
//                Map<String, String> head = new HashMap<>();
                List<KeyValueObject> header = new ArrayList<>();
                KeyValueObject keyValueObject0 = new KeyValueObject();
                keyValueObject0.setType(ValueObjectTypeEnum.BASIC.getType());
                keyValueObject0.setKey("Content-Type");
                keyValueObject0.setValue("application/x-www-form-urlencoded");

                KeyValueObject keyValueObject = new KeyValueObject();
                keyValueObject.setType(ValueObjectTypeEnum.BASIC.getType());
                keyValueObject.setKey("token");
                keyValueObject.setValue(config.getString("token"));
                header.add(keyValueObject0);
                header.add(keyValueObject);
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(String.valueOf(requestData),"post",url, header));
                response =httpClientFunc.apply(request);

//                HttpResponse httpResponse = httpRestTemplate.restTemplate().postForObject(url, null, null, head, null, requestData);
//                String responseStr = EntityUtils.toString(httpResponse.getEntity());
//                response = JSONObject.parseObject(responseStr);
            }catch (Exception e){
                log.error("壹帮贷准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck FuChengCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject result=JSONObject.parseObject(response.getData().toString());
            if (result.getInteger("code")==1) {
                String data = result.getString("data");
                JSONObject datas = JSONObject.parseObject(data);
                if (datas.getInteger("status")==0){
                    return DataVo.success(0, "壹帮贷撞库成功", product.getPlanId());
                }else {
                    return DataVo.fail(1, "壹帮贷撞库失败，请联系系统管理员", product.getPlanId());
                }
            } else {
                return DataVo.fail(1, "壹帮贷撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            return DataVo.fail(1, "壹帮贷撞库失败，请联系系统管理员", product.getPlanId());
        }
    }


}
