package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;


/**
 * @Author Liu Tao
 * @Date 2024 03 21 13 43
 **/
@Slf4j
@Service
public class YiZhanShiShuZhiPingTaiCreditService implements LoanDockingApi {



    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.YiZhanShiShuZhiPingTai;
    }


    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc,Function<String,Object> redisGetFunction,Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit YiZhanShiShuZhiPingTaiCreditService qualityCheck begin...userId:{}", userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("一站式数字平台对接参数:{}", JSONObject.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck YiZhanShiShuZhiPingTaiCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, phoneMd5);
            HttpApiResponse response = null;
            try{
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(phoneMd5,"post",url));
                response = httpClientFunc.apply(request);
            } catch (Exception e) {
                log.error("一站式数字平台准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck YiZhanShiShuZhiPingTaiCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
              JSONObject jsonObject=JSONObject.parseObject(response.getData().toString());
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getString("code").equals("200")) {
                return DataVo.success(0, "一站式数字平台撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "一站式数字平台撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("一站式数字平台撞库失败", e);
            return DataVo.fail(1, "一站式数字平台撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

}
