package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.client.vo.DataVo;

import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;

import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Objects;

/**
 * @Descrption
 * @Author: chend
 * @Date: 2023/2/6
 * @Version V1.0
 **/
@Slf4j
@Service
public class YukuaihuaCreditService implements LoanDockingApi {



    private final static String checkPath = "api/External/hit_library";
    private final static String applyPath = "api/External/create";

    @Data
    private static class Result {
        private Integer code;

        private String msg;

        private Long time;

        private Object data;
    }

    @Data
    private static class CheckInfo {
        private String userPhone;
    }

    @Override
        public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc,Function<String,Object> redisGetFunction,Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit YukuaihuaCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
//            XdProductJointConfig xdProductJointConfig = xdProductJointConfigMapper.selectById(product.getJointType());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("愉快花对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setUserPhone(userInfo.getUserMobileMD5());
            String url = config.getString("url") + checkPath;
            log.info("credit qualityCheck YukuaihuaCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
//            Result response = null;
            HttpApiResponse response = null;
            try {
//                response = httpRestTemplate.restTemplate().postForObject(url, checkInfo, Result.class);
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(JSON.toJSONString(checkInfo),"post",url));
                response =httpClientFunc.apply(request);
            } catch (Exception e) {
                log.error("愉快花准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck YukuaihuaCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject result=JSONObject.parseObject(response.getData().toString());
            return Objects.equals(1, result.getInteger("code")) ? DataVo.success(0, "愉快花撞库成功", product.getPlanId())
                    : DataVo.fail(result.getString("msg"), product.getPlanId());

        } catch (Exception e) {
            log.error("愉快花撞库失败", e);
            return DataVo.fail(1, "愉快花撞库失败，请联系系统管理员", product.getPlanId());
        }
    }
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.YuKuaiHua;
    }

}
