package com.hrsk.cloud.eg.domain.api.channel.guide.common;

import com.hrsk.cloud.eg.domain.api.ApiContext;
import com.hrsk.cloud.eg.domain.api.channel.guide.func.FunctionObject;
import com.hrsk.cloud.eg.domain.api.channel.guide.resolver.vo.ValueObjectResolverManager;
import com.hrsk.cloud.eg.domain.common.GsonUtils;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import org.apache.commons.lang3.StringUtils;
import org.springframework.util.CollectionUtils;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**
 * @author: bianlanzhou
 * @create: 2024-07-27 10:21
 * @description: 值对象
 **/

@ToString
public class ValueObject implements Serializable {
    /**
     * 值类型
     */
    private String type;
    /**
     * 值
     */
    @Getter
    private String value;
    /**
     * 真实值
     */
    @Getter
    private Object realValue;
    /**
     * 函数链
     */
    @Setter
    private List<FunctionObject> functions = new ArrayList<>();

    /**
     * 构造函数
     */
    public ValueObject() {
    }

    /**
     * 构造函数
     * @param value 值
     */
    public ValueObject(String value) {
        this.value = value;
    }

    /**
     * 解析
     * @param apiContext
     * @return
     */
    public ValueObject compile(ApiContext apiContext){
        this.realValue = ValueObjectResolverManager.getInstance().resolve(this,apiContext);
        if(CollectionUtils.isEmpty(functions)){
            return this;
        }
        for(FunctionObject function : functions){
            this.realValue = function.apply(realValue,apiContext);
        }
        return this;
    }

    /**
     * 类型
     * @return 类型
     */
    public String getType(){
        return StringUtils.isEmpty(type) ? typeInference():type;
    }

    /**
     * 类型推测
     * @return 类型
     */
    private String typeInference(){
        if(GsonUtils.isJson(value)){
            return ValueObjectTypeEnum.JSON_PATH.getType();
        }else{
            return ValueObjectTypeEnum.BASIC.getType();
        }
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getValue() {
        return value;
    }

    public void setValue(String value) {
        this.value = value;
    }
}
