package com.hrsk.cloud.eg.domain.api.channel.guide.http;

import com.google.common.collect.Lists;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.ContentTypeEnum;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.KeyValueObject;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.ValueObject;
import lombok.Data;

import java.util.List;

/**
 * @author: bianlanzhou
 * @create: 2024-11-10 21:26
 * @description: HTTP API 请求配置
 **/
@Data
public class HttpApiRequestConfig {
    /**
     * 请求方法
     */
    private String method;
    /**
     * url地址
     */
    private String url;
    /**
     * header
     */
    private List<KeyValueObject> header = Lists.newArrayList();
    /**
     * path  a/b/b
     */
    private List<ValueObject> path = Lists.newArrayList();
    /**
     * search
     */
    private List<KeyValueObject> search = Lists.newArrayList();
    /**
     * 内容类型
     */
    private String contentType = ContentTypeEnum.APPLICATION_JSON.getCode();
    /**
     * body
     */
    private String body;

    /**
     * @description: post 请求方式的方法
     * @param:
     * @return:
     * @author zhangyy
     * @date: 2024/11/16 12:07
     */
    public static HttpApiRequestConfig postRequest(String body, String method, String url) {

        HttpApiRequestConfig httpApiRequestConfig = new HttpApiRequestConfig();
        httpApiRequestConfig.setMethod(method);
        httpApiRequestConfig.setUrl(url);
        httpApiRequestConfig.setBody(body);
        return httpApiRequestConfig;
    }

    /**
     *
     * @param body
     * @param method
     * @param url
     * @param header 请求头
     * @return
     */
    public static HttpApiRequestConfig postRequest(String body, String method, String url,List<KeyValueObject> header) {

        HttpApiRequestConfig httpApiRequestConfig = new HttpApiRequestConfig();
        httpApiRequestConfig.setMethod(method);
        httpApiRequestConfig.setUrl(url);
        httpApiRequestConfig.setBody(body);
        httpApiRequestConfig.setHeader(header);
        return httpApiRequestConfig;
    }
}
