package com.hrsk.cloud.eg.domain.common;

import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.constant.SysErrorCodeEnum;
import com.hrsk.pangu.tool.exception.SysException;
import lombok.extern.slf4j.Slf4j;
import org.beetl.core.Configuration;
import org.beetl.core.GroupTemplate;
import org.beetl.core.Template;
import org.beetl.core.resource.StringTemplateResourceLoader;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

/**
 * @author: bianlanzhou
 * @create: 2024-11-12 17:32
 * @description: beetl帮助类 此方法使用spring bean周期，spring启动前不可用
 **/
@Slf4j
@Component
public class BeetlHelper implements InitializingBean {
    /**
     * TEMPLATE
     */
    private static GroupTemplate GT = null;

    /**
     * 解析 {success: ${data.httpStatus == 200 ? true : false} , data: ${data.data}}
     * @param templateStr
     * @param input
     * @return
     */
    public static String render(String templateStr, Object input){
        Template template = GT.getTemplate(templateStr);
        template.binding("response", input);
        try {
            return template.render();
        } catch (Exception e) {
            log.error("模板渲染失败!template:{}",templateStr,e);
            throw new SysException(SysErrorCodeEnum.BEETL_ERROR.getCode(),SysErrorCodeEnum.BEETL_ERROR.getMessage());
        }
    }

    @Override
    public void afterPropertiesSet() throws Exception {
        StringTemplateResourceLoader resourceLoader = new StringTemplateResourceLoader();
        Configuration cfg = null;
        try {
            cfg = Configuration.defaultConfiguration();
        } catch (IOException e) {
            log.error("初始化BEETLE配置失败!",e);
        }
        GT = new GroupTemplate(resourceLoader, cfg);
        log.info("完成Beetl工具类加载 ...");
    }


    public static void main(String[] args) throws Exception {
        HttpApiResponse response = new HttpApiResponse(200,"<html>\n" +
                "<meta http-equiv=\"refresh\" content=\"0;url=http://www.baidu.com/\">\n" +
                "</html>");
        Map<String,Object> map = new HashMap<>();
        map.put("httpStatus",200);
        map.put("data","<html>\n" +
                "<meta http-equiv=\"refresh\" content=\"0;url=http://www.baidu.com/\">\n" +
                "</html>");
        new BeetlHelper().afterPropertiesSet();
        System.out.println(BeetlHelper.render("{success: ${response.httpStatus == 200 ? true : false} , data: ${response.data}}",map));
    }
}
