package com.hrsk.cloud.eg.domain.common;

import com.caucho.hessian.io.Hessian2Input;
import com.caucho.hessian.io.Hessian2Output;
import lombok.extern.slf4j.Slf4j;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;

/**
 * @author: bianlanzhou
 * @create: 2024-08-02 08:43
 * @description: hessian工具类
 **/
@Slf4j
public class HessianUtils {
    public static byte[] serialize(Object object){
        Hessian2Output ho = null;
        try{
            ByteArrayOutputStream bos = new ByteArrayOutputStream();
            ho = new Hessian2Output(bos);
            ho.writeObject(object);
            ho.flush();
            return bos.toByteArray();
        } catch (IOException e) {
            log.error("序列化对象异常!",e);
            //throw new SysException("序列化对象异常!",e);
            throw new RuntimeException("序列化对象异常!",e);
        }finally {
            if(ho !=null){
                try {
                    ho.close();
                } catch (IOException e) {
                    log.error("序列化流关闭失败!",e);
                }
            }
        }
    }

    /** Hessian反序列化 */
    public static Object deserialize(byte[] bytes){
        Hessian2Input hi = null;
        try{
            ByteArrayInputStream is = new ByteArrayInputStream(bytes);
            hi = new Hessian2Input(is);
            return hi.readObject();
        }catch (Exception e){
            log.error("反序列化对象异常!",e);
            //throw new SysException("反序列化对象异常!",e);
            throw new RuntimeException("反序列化对象异常!",e);
        }finally {
            if(hi !=null){
                try {
                    hi.close();
                } catch (IOException e) {
                    log.error("序列化流关闭失败!",e);
                }
            }
        }
    }

}
