package com.hrsk.cloud.eg.infrastructure.gatewayimpl;

import com.google.gson.JsonElement;
import com.hrsk.cloud.eg.client.dto.cmd.ApiInvokeCmd;
import com.hrsk.cloud.eg.domain.api.Api;
import com.hrsk.cloud.eg.domain.api.ApiFactory;
import com.hrsk.cloud.eg.domain.api.ApiGateway;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.GsonUtils;
import com.hrsk.cloud.eg.infrastructure.client.http.HttpClient;
import com.hrsk.cloud.eg.infrastructure.repository.database.dao.EgressApiChannelDao;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.EgressApiChannelDo;
import com.hrsk.cloud.eg.infrastructure.service.EgApiChannelService;
import com.hrsk.cloud.eg.infrastructure.utils.RedisUtil;
import com.hrsk.pangu.tool.exception.BizException;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.EgressApiErrorCodeEnum;
import javax.annotation.Resource;
import java.util.List;
import java.util.concurrent.TimeUnit;
import java.util.stream.Collectors;
import com.hrsk.cloud.eg.domain.api.ApiChannel;
/**
 * @author: bianlanzhou
 * @create: 2024-09-06 13:54
 * @description: API网关防腐层实现类
 **/
@Slf4j
@Component
public class ApiGatewayImpl implements ApiGateway {
    @Resource
    private HttpClient httpClient;
    @Resource
    private EgressApiChannelDao egressApiChannelDao;

    @Resource
    private EgApiChannelService egApiChannelService;

    @Resource
    private RedisUtil redisUtil;

    /**
     * 调用
     * @param apiInvokeCmd cmd CMD
     * @return 处理结果
     */
    @Override
    public String invoke(ApiInvokeCmd apiInvokeCmd) {
        List<EgressApiChannelDo> egressApiChannels = egressApiChannelDao.selectByApiCode(apiInvokeCmd.getApiCode());
        if(CollectionUtils.isEmpty(egressApiChannels)){
            throw new BizException(EgressApiErrorCodeEnum.API_CHANNEL_NOT_EXIST.getCode(),
                    EgressApiErrorCodeEnum.API_CHANNEL_NOT_EXIST.getMessage());
        }
        List<ApiChannel> apiChannels = egressApiChannels.stream().
                map(egressApiChannelDO -> ApiFactory.createApiChannel(egressApiChannelDO.getChannelCode(),egressApiChannelDO.getIntegrationMode(),
                        egressApiChannelDO.getRequestConfig(),egressApiChannelDO.getResponseConfig())).collect(Collectors.toList());
        Api api = ApiFactory.createApi(apiChannels);
        return api.route(apiInvokeCmd.getRoute()).invoke(apiInvokeCmd.getData(), input -> {
            ResponseEntity<String> response = httpClient.exchange(input);
            if(GsonUtils.isJson(response.getBody())){
                JsonElement jsonElement = GsonUtils.fromJson(response.getBody(), JsonElement.class);
                if(jsonElement.isJsonObject()){
                    return new HttpApiResponse(response.getStatusCodeValue(),jsonElement.getAsJsonObject());
                }else if(jsonElement.isJsonArray()){
                    return new HttpApiResponse(response.getStatusCodeValue(),jsonElement.getAsJsonArray());
                }else{
                    return new HttpApiResponse(response.getStatusCodeValue(),jsonElement.getAsJsonPrimitive());
                }
            }
            else{
                return new HttpApiResponse(response.getStatusCodeValue(),response.getBody());
            }
        },key->{
          Object object = redisUtil.get(key);
           return  object;
       },
        (redisSetDto)->{
          return    redisUtil.setValue(redisSetDto.getKey(),redisSetDto.getValue(),redisSetDto.getTime(), redisSetDto.getTimeUnit());
        });
    }

    public static void main(String[] args) {
        JsonElement jsonElement = GsonUtils.fromJson("<html>123</html>",JsonElement.class);
        System.out.println(jsonElement);
    }
}
