package com.hrsk.cloud.eg.infrastructure.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.hrsk.cloud.eg.client.constant.GlobalDataStatusEnum;
import com.hrsk.cloud.eg.domain.common.GsonUtils;
import com.hrsk.cloud.eg.infrastructure.repository.database.dao.EgressApiChannelDao;
import com.hrsk.cloud.eg.infrastructure.repository.database.dao.EgressApiDao;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.*;
import com.hrsk.cloud.eg.infrastructure.repository.database.dao.EgApiLoanExtendDao;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.RedisUtil;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Objects;

import static com.hrsk.cloud.eg.infrastructure.constant.RedisConstant.BUSINESS_API_KEY;

/**
 * @author zhangyy
 * @version 1.0
 * @description: EgApiServiceImpl
 * @date 2024/8/28 11:01
 */
@Service
public class EgApiServiceImpl extends ServiceImpl<EgressApiDao, EgressApiDo> implements EgApiService {

    @Resource
    private EgressApiChannelDao egApiChannelDao;

    @Resource
    private EgApiLoanExtendDao egApiLoanExtendDao;

    @Resource
    private RedisUtil   redisUtil;

    @Override
    public EgLoanApiConfigInfoDo getLoanApiConfigInfo(Integer apiId) {
        EgLoanApiConfigInfoDo egLoanApiConfigInfoDo=new EgLoanApiConfigInfoDo();
        EgressApiDo egApiDo = baseMapper.selectById(apiId);
        if (Objects.isNull(egApiDo)) {
            return new EgLoanApiConfigInfoDo();
        }
        egLoanApiConfigInfoDo.setApiName(egApiDo.getApiName());
        egLoanApiConfigInfoDo.setApiType(egApiDo.getApiType());
        egLoanApiConfigInfoDo.setApiId(egApiDo.getId());
        //查询对应的配置
        LambdaQueryWrapper<EgressApiChannelDo> queryWrapper=new LambdaQueryWrapper<>();
        queryWrapper.eq(EgressApiChannelDo::getApiId, apiId);
        queryWrapper.eq(EgressApiChannelDo::getStatus, GlobalDataStatusEnum.YES.getCode());
        queryWrapper.orderByDesc(EgressApiChannelDo::getId);
        queryWrapper.last("limit 1");

        EgressApiChannelDo egApiEndpointDos = egApiChannelDao.selectOne(queryWrapper);
        if (Objects.isNull(egApiEndpointDos)) {
            return egLoanApiConfigInfoDo;
        }
        egLoanApiConfigInfoDo.setRequestConfig(HessianUtils.serialize(egApiEndpointDos.getRequestConfig()));

        //查询扩展配置
        LambdaQueryWrapper<EgApiLoanExtendDo> extendDoLambdaQueryWrapper=new LambdaQueryWrapper<>();
        extendDoLambdaQueryWrapper.eq(EgApiLoanExtendDo::getApiId, egApiEndpointDos.getId());
        extendDoLambdaQueryWrapper.eq(EgApiLoanExtendDo::getStatus, GlobalDataStatusEnum.YES.getCode());
        extendDoLambdaQueryWrapper.orderByDesc(EgApiLoanExtendDo::getId);
        extendDoLambdaQueryWrapper.last("limit 1");
        EgApiLoanExtendDo egApiLoanExtendDo = egApiLoanExtendDao.selectOne(extendDoLambdaQueryWrapper);
        if (Objects.isNull(egApiLoanExtendDo)) {
            return egLoanApiConfigInfoDo;
        }
        egLoanApiConfigInfoDo.setNeedCheck(egApiLoanExtendDo.getCheckInto());
        return egLoanApiConfigInfoDo;
    }

    @Override
    public EgLoanApiConfigInfoDo getApiInfoByRedis(Integer apiId) {
        String key = String.format(BUSINESS_API_KEY, apiId);
        Object value = redisUtil.get(key);
        if (null == value || StringUtils.isBlank((String) value)) {
            EgLoanApiConfigInfoDo api = getLoanApiConfigInfo(apiId);
            if (null != api) {
                redisUtil.set(key, GsonUtils.toJson(api));
            }
            return api;
        }
        return GsonUtils.fromJson((String) value, EgLoanApiConfigInfoDo.class);
    }
}
