package com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.RedisSetDto;
import com.hrsk.cloud.eg.client.dto.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.client.dto.plan.command.PlanCmd;
import com.hrsk.cloud.eg.client.dto.user.command.UserBaseInfoCmd;

import com.hrsk.cloud.eg.client.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.channel.customized.common.ServerCodeEnums;
import com.hrsk.cloud.eg.domain.api.channel.customized.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequestConfig;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.common.HessianUtils;
import com.hrsk.cloud.eg.domain.common.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.BadPaddingException;
import javax.crypto.Cipher;
import javax.crypto.IllegalBlockSizeException;
import javax.crypto.NoSuchPaddingException;
import javax.crypto.spec.SecretKeySpec;
import java.io.UnsupportedEncodingException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.util.*;

/**
 * 徐州富力API接单
 */
@Service
@Slf4j
public class XuzhoufuliCreditService implements LoanDockingApi {


    private final String qualityCheckPath = "/checkPhone";

    private final String applyPath = "/push";

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.Xuzhoufuli;
    }

    @Data
    public static class CheckData{
        private String merNo;
        private String params;
    }

    @Data
    private static class CheckInfo{
        private String phoneMd5;

        private String sign;


    }
    @Data
    private static class ResultHt{
        private String code;
        private String message;
    }
    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *  {"channelSource":"birong","url":"http://apitest.shlyxxjs.com","key":"mgjr@3des123#dhjr9763089"}
     */
    @Override
         public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo, Function<HttpApiRequest, HttpApiResponse> httpClientFunc, Function<String,Object> redisGetFunction, Function<RedisSetDto,Boolean> redisSetFunction)  {
        try {
            log.info("credit XuzhoufuliCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
//            XdProductJointConfig xdProductJointConfig = xdProductJointConfigMapper.selectById(product.getJointType());
           
            String configJson = HessianUtils.deserialize(configInfo.getRequestConfig()).toString();
            JSONObject xuzhoufuliJointDTO = JSON.parseObject(configJson);
            log.info("徐州富力对接参数:{}", JSON.toJSONString(xuzhoufuliJointDTO));

            String phoneMd5 = userInfo.getUserMobileMD5();
            TreeMap<String, Object> paramMap = new TreeMap<>();
            paramMap.put("phoneMd5", phoneMd5);
            String paramString = mapToURL(paramMap);
            String signKey = xuzhoufuliJointDTO.getString("signKey");
            String signValue = paramString + "&key=" + signKey;
            String sign = Md5Util.encoderByMd5(signValue);

            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setSign(sign);
            checkInfo.setPhoneMd5(phoneMd5);
            CheckData data = new CheckData();
            data.setMerNo(xuzhoufuliJointDTO.getString("merNo") );
            String params = AesUtil.encrypt(JSON.toJSONString(checkInfo), xuzhoufuliJointDTO.getString("encKey"));
            data.setParams(params);
            String url = xuzhoufuliJointDTO.getString("url") + qualityCheckPath;
            log.info("credit qualityCheck XuzhoufuliCreditService request userId:{}, url:{}, data:{}",userInfo.getUserId(), url, data);
            HttpApiResponse response = null;
            try{
                HttpApiRequest request=new HttpApiRequest(HttpApiRequestConfig.postRequest(JSON.toJSONString(data),"post",url));
                response =httpClientFunc.apply(request);
            }catch (Exception e){
                log.error("徐州富力准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck XuzhoufuliCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject result=JSONObject.parseObject(response.getData().toString());
            return Objects.equals("200", result.getInteger("code")) ? DataVo.success(0, "徐州富力撞库成功", product.getPlanId())
                    :DataVo.fail(result.getString("message"), product.getPlanId());
        } catch (Exception e) {
            log.error("徐州富力撞库失败", e);
            return DataVo.fail(1, "徐州富力撞库失败，请联系系统管理员", product.getPlanId());
        }

    }


    public String mapToURL(Map<String, Object> paramMap) {
        StringBuffer sb = new StringBuffer();
        List<String> keySet = new ArrayList<String>(paramMap.keySet());
        Collections.sort(keySet);
        for (int i = 0; i < paramMap.size(); i++) {
            sb.append("&").append(keySet.get(i)).append("=").append(
                    paramMap.get(keySet.get(i)));
        }
        sb.delete(0, 1);
        return sb.toString();
    }

    public static class AesUtil {

        /**
         * 默认的字符编码
         */
        private static final String DEFAULT_CHARSET = "utf-8";
        /**
         * 算法/模式/填充
         **/
        private static final String CipherMode = "AES/ECB/PKCS5Padding";
        /**
         * 算法
         */
        private static String ALGORITHM = "AES";

        /**
         * 解密AES 32位
         *
         * @param sSrc      解密的内容
         * @param secretKey 秘钥
         * @return 解密后的明文 数据
         */
        public static String decrypt(String sSrc, String secretKey) {

            if (secretKey == null) {

                return null;
            }
            try {
                byte[] raw = secretKey.getBytes(DEFAULT_CHARSET);
                SecretKeySpec secretKeySpec = new SecretKeySpec(raw, ALGORITHM);
                Cipher cipher = Cipher.getInstance(CipherMode);
                cipher.init(Cipher.DECRYPT_MODE, secretKeySpec);
                // 先用base64解密
                byte[] encryptedArr = Base64.getDecoder().decode(sSrc);
                byte[] original = cipher.doFinal(encryptedArr);
                return new String(original, DEFAULT_CHARSET);
            } catch (Exception ex) {
                return null;
            }
        }


        /**
         * 加密32位
         *
         * @param sSrc 需要加密的内容
         * @param sKey 秘钥
         * @return 加密的内容
         */
        public static String encrypt(String sSrc, String sKey) {
            SecretKeySpec keySpec = null;
            try {
                keySpec = new SecretKeySpec(sKey.getBytes("UTF-8"), "AES");
                Cipher cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");
                cipher.init(Cipher.ENCRYPT_MODE, keySpec);
                byte[] bytes = cipher.doFinal(sSrc.getBytes("utf-8"));
                return parseByte2HexStr(bytes);
            } catch (UnsupportedEncodingException e) {
                e.printStackTrace();
            } catch (NoSuchPaddingException e) {
                e.printStackTrace();
            } catch (IllegalBlockSizeException e) {
                e.printStackTrace();
            } catch (NoSuchAlgorithmException e) {
                e.printStackTrace();
            } catch (BadPaddingException e) {
                e.printStackTrace();
            } catch (InvalidKeyException e) {
                e.printStackTrace();
            }
            return null;
        }

        private static String parseByte2HexStr(byte[] buf) {
            StringBuffer sb = new StringBuffer();

            for (int i = 0; i < buf.length; i++) {

                String hex = Integer.toHexString(buf[i] & 0xFF);

                if (hex.length() == 1) {

                    hex = '0' + hex;

                }

                sb.append(hex.toUpperCase());

            }
            return sb.toString();

        }
    }
}
